import '../node_modules/.pnpm/@asgardeo_auth-react@4.0.4_@babel_runtime-corejs3@7.24.5_react-dom@18.3.1_react-router-dom@4.3.1_react@18.3.1/node_modules/@asgardeo/auth-react/dist/main.js';
import { IdentityAppsApiException } from '@thiva/core/exceptions';
import { HttpMethods } from '@thiva/core/models';
import useRequest from '@thiva/admin.core.v1/hooks/use-request';
import { store } from '@thiva/admin.core.v1/store';
import { m as main } from '../_virtual/main.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * Get an axios instance.
 */
const httpClient = main.exports.AsgardeoSPAClient.getInstance()
    .httpRequest.bind(main.exports.AsgardeoSPAClient.getInstance());
/**
 * Get API resources for the identifier validation.
 * Only to be used for the identifier validation.
 *
 * @param filter - filter.
 * @returns `Promise<APIResourcesListInterface | IdentityAppsApiException>`
 */
const getAPIResourcesForIdenitifierValidation = (filter) => {
    const requestConfig = {
        headers: {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        method: HttpMethods.GET,
        params: {
            filter
        },
        url: `${store.getState().config.endpoints.apiResources}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        if (response.status === 200) {
            return Promise.resolve(response.data);
        }
        else {
            throw new IdentityAppsApiException(response.data.description, null, response.status, response.request, response, response.config);
        }
    })
        .catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};
/**
 * Get API resources.
 *
 * @param after - after.
 * @param before - before.
 * @param filter - filter.
 * @param shouldFetch - whether to fetch or not.
 * @returns `Promise<APIResourcesListInterface>`
 * @throws `IdentityAppsApiException`
 */
const useAPIResources = (after, before, filter, shouldFetch = true, attributes) => {
    const requestConfig = {
        headers: {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        method: HttpMethods.GET,
        params: {
            after,
            attributes,
            before,
            filter
        },
        url: `${store.getState().config.endpoints.apiResources}`
    };
    const { data, error, isValidating, mutate } = useRequest(shouldFetch ? requestConfig : null);
    return {
        data,
        error: error,
        isLoading: !error && !data,
        isValidating,
        mutate
    };
};
/**
 *
 * @param apiResourceId - id of the API resource
 * @returns `Promise<APIResourceInterface>`
 * @throws `IdentityAppsApiException`
 */
const useAPIResourceDetails = (apiResourceId) => {
    const requestConfig = {
        headers: {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        method: HttpMethods.GET,
        url: `${store.getState().config.endpoints.apiResources}/${apiResourceId}`
    };
    /**
     * Pass `null` if the `apiResourceId` is not available. This will prevent the request from being called.
     */
    const { data, error, isValidating, mutate } = useRequest(apiResourceId ? requestConfig : null);
    return {
        data,
        error: error,
        isLoading: !error && !data,
        isValidating,
        mutate
    };
};
/**
 * Get permissions of an API resource for the permission validation.
 * Only to be used for the permission validation.
 *
 * @param filter - filter.
 * @returns `Promise<APIResourcePermissionInterface[]>`
 * @throws `IdentityAppsApiException`
 */
const getAPIResourcePermissions = (filter) => {
    const requestConfig = {
        headers: {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        method: HttpMethods.GET,
        params: { filter },
        url: `${store.getState().config.endpoints.scopes}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        if (response.status === 200) {
            return Promise.resolve(response.data);
        }
        else {
            throw new IdentityAppsApiException(response.data.description, null, response.status, response.request, response, response.config);
        }
    })
        .catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};
/**
 * Delete an API resource.
 *
 * @param apiResourceId - UUID of the API resource that needed to be deleted.
 * @returns `Promise<null | IdentityAppsApiException>`
 * @throws `IdentityAppsApiException`
 */
const deleteAPIResource = (apiResourceId) => {
    const requestConfig = {
        headers: {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        method: HttpMethods.DELETE,
        url: `${store.getState().config.endpoints.apiResources}/${apiResourceId}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        if (response.status !== 204) {
            throw new IdentityAppsApiException(response.data.description, null, response.status, response.request, response, response.config);
        }
        return Promise.resolve(response.data);
    }).catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};
/**
 * Update an API resource.
 *
 * @param apiResourceId - UUID of the API resource that needed to be updated.
 * @param updateAPIResourceBody - Body of the API resource that needed to be updated.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
const updateAPIResource = (apiResourceId, updateAPIResourceBody) => {
    const requestConfig = {
        data: updateAPIResourceBody,
        method: HttpMethods.PATCH,
        url: `${store.getState().config.endpoints.apiResources}/${apiResourceId}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        return Promise.resolve(response.data);
    })
        .catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};
/**
 * Create an API resource.
 *
 * @param apiResourceBody - Body of the API resource that needed to be created.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
const createAPIResource = (apiResourceBody) => {
    const requestConfig = {
        data: apiResourceBody,
        method: HttpMethods.POST,
        url: `${store.getState().config.endpoints.apiResources}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        return Promise.resolve(response.data);
    })
        .catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};
/**
 * Delete a scope from an API resource.
 *
 * @param apiResourceId - UUID of the API resource.
 * @param deleteScopeName - Name of the scope that needs to be deleted.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
const deleteScopeFromAPIResource = (apiResourceId, deletingScopeName) => {
    const requestConfig = {
        method: HttpMethods.DELETE,
        url: `${store.getState().config.endpoints.apiResources}/${apiResourceId}/scopes/${deletingScopeName}`
    };
    return httpClient(requestConfig)
        .then((response) => {
        return Promise.resolve(response.data);
    })
        .catch((error) => {
        var _a, _b;
        throw new IdentityAppsApiException(error.message, error.stack, (_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.code, error.request, error.response, error.config);
    });
};

export { createAPIResource, deleteAPIResource, deleteScopeFromAPIResource, getAPIResourcePermissions, getAPIResourcesForIdenitifierValidation, updateAPIResource, useAPIResourceDetails, useAPIResources };
