import { Form, Field } from '@thiva/form';
import { useDocumentation, EmphasizedSegment, DocumentationLink, ContentLoader } from '@thiva/react-components';
import React__default from 'react';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * Authorization part of the edit API Resource page.
 *
 * @param props - Props injected to the component.
 * @returns Authorization part of the edit API Resource page component
 */
const AuthorizationAPIResource = (props) => {
    const { apiResourceData, isAPIResourceDataLoading, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const { getLink } = useDocumentation();
    return (!isAPIResourceDataLoading
        ? (React__default.createElement(React__default.Fragment, null, React__default.createElement(EmphasizedSegment, { padded: "very" },
            React__default.createElement(Form, { "data-componentid": `${componentId}-form`, onSubmit: () => null, id: `${componentId}-form`, uncontrolledForm: false },
                React__default.createElement(Field.Checkbox, { ariaLabel: "authorization", name: "authorization", label: t("extensions:develop.apiResource.tabs.authorization.form" +
                        ".fields.authorize.label"), hint: (React__default.createElement(React__default.Fragment, null,
                        t("extensions:develop.apiResource.tabs.authorization.form" +
                            ".fields.authorize.hint"),
                        React__default.createElement(DocumentationLink, { link: getLink("develop.apiResources.addAPIResource." +
                                "requiredAuthorization.learnMore") }, t("extensions:common.learnMore")))), width: 16, defaultValue: apiResourceData.requiresAuthorization, readOnly: true, "data-componentid": `${componentId}-authorize` })))))
        : React__default.createElement(ContentLoader, { dimmer: true }));
};
/**
 * Default props for the component.
 */
AuthorizationAPIResource.defaultProps = {
    "data-componentid": "authorization-api-resource"
};

export { AuthorizationAPIResource };
