import { Show } from '@thiva/access-control';
import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { Form, Field } from '@thiva/form';
import { EmphasizedSegment, CopyInputField, ConfirmationModal, ContentLoader, DangerZoneGroup, DangerZone } from '@thiva/react-components';
import React__default, { useState } from 'react';
import '../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import Divider from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Divider/Divider.js';
import { history } from '@thiva/admin.core.v1';
import { deleteAPIResource } from '../../api/api-resources.js';
import { APIResourcesConstants } from '../../constants/api-resources-constants.js';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';
import { useSelector } from '../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const FORM_ID = "apiResource-general-details";
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const GeneralAPIResource = (props) => {
    const { isReadOnly, isSubmitting, handleUpdateAPIResource, apiResourceData, isAPIResourceDataLoading, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    const featureConfig = useSelector((state) => state.config.ui.features);
    const [isFormValidationError, setIsFormValidationError] = useState(true);
    const [deleteAPIResourceLoading, setDeleteAPIResourceLoading] = useState(false);
    const [showDeleteConfirmationModal, setShowDeleteConfirmationModal] = useState(false);
    const [deletingAPIResource, setDeletingAPIResource] = useState(undefined);
    /**
     * Deletes an API resource when the delete API resource button is clicked.
     *
     * @param apiResourceId - API resource ID.
     */
    const handleAPIResourceDelete = (apiResourceId) => {
        setDeleteAPIResourceLoading(true);
        deleteAPIResource(apiResourceId)
            .then(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.deleteAPIResource.success" +
                    ".description"),
                level: AlertLevels.SUCCESS,
                message: t("extensions:develop.apiResource.notifications.deleteAPIResource.success.message")
            }));
            setShowDeleteConfirmationModal(false);
            history.push(APIResourcesConstants.getPaths().get("API_RESOURCES"));
        })
            .catch(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.deleteAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.deleteAPIResource" +
                    ".genericError.message")
            }));
        })
            .finally(() => {
            setDeleteAPIResourceLoading(false);
            setDeletingAPIResource(undefined);
        });
    };
    /**
     * Show danger zone component
     *
     * @returns `ReactElement`
     */
    const resolveDangerActions = () => {
        var _a, _b;
        return (React__default.createElement(React__default.Fragment, null, !isReadOnly &&
            (React__default.createElement(Show, { when: (_b = (_a = featureConfig === null || featureConfig === void 0 ? void 0 : featureConfig.apiResources) === null || _a === void 0 ? void 0 : _a.scopes) === null || _b === void 0 ? void 0 : _b.delete },
                React__default.createElement(DangerZoneGroup, { sectionHeader: t("extensions:develop.apiResource.tabs.general.dangerZoneGroup.header") },
                    React__default.createElement(DangerZone, { "data-testid": `${componentId}-danger-zone`, actionTitle: t("extensions:develop.apiResource.tabs.general.dangerZoneGroup" +
                            ".deleteApiResource.button"), header: t("extensions:develop.apiResource.tabs.general.dangerZoneGroup" +
                            ".deleteApiResource.header"), subheader: t("extensions:develop.apiResource.tabs.general.dangerZoneGroup" +
                            ".deleteApiResource.subHeading"), onActionClick: () => {
                            setShowDeleteConfirmationModal(true);
                            setDeletingAPIResource(apiResourceData);
                        }, isButtonDisabled: false }))))));
    };
    /**
     * Prepare form values for submitting.
     *
     * @param values - Form values.
     * @returns Sanitized form values.
     */
    const updateConfigurations = (values) => {
        var _a;
        handleUpdateAPIResource({
            name: (_a = values.displayName) === null || _a === void 0 ? void 0 : _a.toString().trim()
        });
    };
    /**
     * Validates the Form.
     *
     * @param values - Form Values.
     * @returns Form validation.
     */
    const validateForm = (values) => {
        var _a;
        const errors = {
            displayName: undefined
        };
        if (!((_a = values.displayName) === null || _a === void 0 ? void 0 : _a.toString().trim())) {
            errors.displayName = t("extensions:develop.apiResource.tabs.general.form" +
                ".fields.name.emptyValidate");
            setIsFormValidationError(true);
        }
        else {
            setIsFormValidationError(false);
        }
        return errors;
    };
    return (!isAPIResourceDataLoading
        ? (React__default.createElement(React__default.Fragment, null,
            React__default.createElement(EmphasizedSegment, { padded: "very" },
                React__default.createElement(Form, { "data-testid": `${componentId}-form`, onSubmit: updateConfigurations, id: FORM_ID, validate: validateForm, uncontrolledForm: false },
                    apiResourceData.name && (React__default.createElement(Field.Input, { ariaLabel: "Site title input field", inputType: "name", name: "displayName", label: t("extensions:develop.apiResource.tabs.general.form" +
                            ".fields.name.label"), placeholder: t("extensions:develop.apiResource.tabs." +
                            "general.form.fields.name.placeholder"), readOnly: isReadOnly, required: true, initialValue: apiResourceData.name, maxLength: 100, minLength: 0, width: 16, "data-componentid": `${componentId}-general-form-displayName` })),
                    apiResourceData.identifier && (React__default.createElement(Field.Input, { ariaLabel: "Site title input field", inputType: "url", name: "identifier", label: t("extensions:develop.apiResource.tabs.general.form" +
                            ".fields.identifier.label"), readOnly: true, required: true, maxLength: 100, minLength: 0, width: 16, "data-componentid": `${componentId}-general-form-identifier` },
                        React__default.createElement(CopyInputField, { value: apiResourceData.identifier }))),
                    React__default.createElement(Field.Button, { form: FORM_ID, size: "small", buttonType: "primary_btn", ariaLabel: "Update button", name: "update-button", hidden: isReadOnly, disabled: isSubmitting || isFormValidationError, loading: isSubmitting, "data-componentid": `${componentId}-submit-button`, label: t("extensions:develop.apiResource.tabs.general.form" +
                            ".updateButton") }))),
            React__default.createElement(Divider, { hidden: true }),
            resolveDangerActions(),
            deletingAPIResource && (React__default.createElement(ConfirmationModal, { primaryActionLoading: deleteAPIResourceLoading, onClose: () => setShowDeleteConfirmationModal(false), type: "negative", open: showDeleteConfirmationModal, assertionHint: t("extensions:develop.apiResource.confirmations.deleteAPIResource." +
                    "assertionHint"), assertionType: "checkbox", primaryAction: t("common:confirm"), secondaryAction: t("common:cancel"), onSecondaryActionClick: () => {
                    setShowDeleteConfirmationModal(false);
                }, onPrimaryActionClick: () => handleAPIResourceDelete(deletingAPIResource.id), "data-testid": `${componentId}-delete-confirmation-modal`, closeOnDimmerClick: false },
                React__default.createElement(ConfirmationModal.Header, { "data-testid": `${componentId}-delete-confirmation-modal-header` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.header")),
                React__default.createElement(ConfirmationModal.Message, { attached: true, negative: true, "data-testid": `${componentId}-delete-confirmation-modal-message` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.message")),
                React__default.createElement(ConfirmationModal.Content, { "data-testid": `${componentId}-delete-confirmation-modal-content` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.content"))))))
        : React__default.createElement(ContentLoader, { dimmer: true }));
};
/**
 * Default props for the component.
 */
GeneralAPIResource.defaultProps = {
    "data-componentid": "general-api-resource"
};

export { GeneralAPIResource };
