import Grid from '../../node_modules/.pnpm/@oxygen-ui_react@1.11.0_@emotion_react@11.11.4_@emotion_styled@11.11.5_@mui_icons-material@5._ozrhvdqkt7gkjaiaow64dhg7sa/node_modules/@oxygen-ui/react/Grid/Grid.js';
import { useTrigger } from '@thiva/forms';
import { EmphasizedSegment, Heading, PrimaryButton, ListLayout, EmptyPlaceholder, ConfirmationModal } from '@thiva/react-components';
import React__default, { useState, useEffect } from 'react';
import Icon from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Icon/Icon.js';
import Input from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Input/Input.js';
import { PermissionListAPIResource } from './permission-list-api-resource.js';
import { getEmptyPlaceholderIllustrations } from '@thiva/admin.core.v1';
import '../wizard/add-api-resource.js';
import { AddAPIResourcePermission } from '../wizard/add-api-resource-permission.js';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const PermissionAPIResource = (props) => {
    const { apiResourceData, isAPIResourceDataLoading, isSubmitting, isReadOnly, handleUpdateAPIResource, handleDeleteAPIScope, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const [permissionList, setPermissionList] = useState([]);
    const [serachedPermissionList, setSearchedPermissionList] = useState([]);
    const [deletingAPIResourcePermission, setDeletingAPIResourcePermission] = useState(null);
    const [triggerAddAPIResourcePermissionModal, setTriggerAddAPIResourcePermissionModal] = useTrigger();
    const [permissionSearchQuery, setPermissionSearchQuery] = useState("");
    /**
     * Set the permission list.
     */
    useEffect(() => {
        if (apiResourceData) {
            setPermissionList(apiResourceData.scopes);
            setSearchedPermissionList(apiResourceData.scopes);
        }
    }, [apiResourceData, deletingAPIResourcePermission]);
    /**
     * Handles the search query change.
     *
     * @param event - Change event
     */
    const searchPermission = (event) => {
        const changeValue = event.target.value;
        setPermissionSearchQuery(changeValue);
        if (changeValue.length > 0) {
            // Filter the permission list using the `displayName`
            setSearchedPermissionList(permissionList.filter((permission) => {
                const displayName = permission.displayName;
                return displayName.toLowerCase().includes(changeValue.toLowerCase());
            }));
        }
        else {
            setSearchedPermissionList(permissionList);
        }
    };
    /**
     * Handles the search query clear.
     */
    const clearSearchPermission = () => {
        setPermissionSearchQuery("");
        setSearchedPermissionList(permissionList);
    };
    /**
     * Handles the API resource permission delete action.
     */
    const deletePermission = () => {
        handleDeleteAPIScope(deletingAPIResourcePermission.name, () => setDeletingAPIResourcePermission(null));
    };
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement(EmphasizedSegment, { className: "padded", loading: isAPIResourceDataLoading },
            React__default.createElement(Grid, { container: true, className: "mb-1" },
                React__default.createElement(Grid, { xs: 8 },
                    React__default.createElement(Heading, { as: "h4", compact: true }, t("apiResources:tabs.scopes.title")),
                    React__default.createElement(Heading, { as: "h6", color: "grey", subHeading: true, className: "mb-5" }, t("apiResources:tabs.scopes.subTitle"))),
                React__default.createElement(Grid, { xs: 4, alignItems: "flex-end" }, (permissionList === null || permissionList === void 0 ? void 0 : permissionList.length) !== 0 && !isReadOnly
                    && (React__default.createElement(PrimaryButton, { "data-componentid": `${componentId}-add-permission-button`, size: "medium", floated: "right", onClick: () => setTriggerAddAPIResourcePermissionModal() },
                        React__default.createElement(Icon, { name: "add" }),
                        t("apiResources:tabs.scopes.button"))))),
            React__default.createElement(ListLayout, { showTopActionPanel: !isAPIResourceDataLoading && (permissionList === null || permissionList === void 0 ? void 0 : permissionList.length) > 0, showPagination: false, onPageChange: () => null, totalPages: 100, "data-testid": `${componentId}-list-layout`, totalListSize: permissionList === null || permissionList === void 0 ? void 0 : permissionList.length, leftActionPanel: (React__default.createElement("div", { className: "advanced-search-wrapper aligned-left fill-default" },
                    React__default.createElement(Input, { className: "advanced-search with-add-on", "data-testid": `${componentId}-list-search-input`, icon: "search", iconPosition: "left", onChange: searchPermission, placeholder: t("apiResources:tabs.scopes.search"), floated: "right", size: "small", value: permissionSearchQuery }))) }, !permissionList
                ? (React__default.createElement(EmptyPlaceholder, { subtitle: [t("extensions:develop.apiResource.apiResourceError." +
                            "subtitles.0"),
                        t("extensions:develop.apiResource.apiResourceError.subtitles.1")], title: t("extensions:develop.apiResource.apiResourceError.title"), image: getEmptyPlaceholderIllustrations().genericError, imageSize: "tiny" }))
                : (React__default.createElement(PermissionListAPIResource, { isAPIResourceDataLoading: isAPIResourceDataLoading, isReadOnly: isReadOnly, permissionList: permissionList, serachedPermissionList: serachedPermissionList, isSubmitting: isSubmitting, clearSearchPermission: clearSearchPermission, setRemovePermission: setDeletingAPIResourcePermission, setTriggerAddAPIResourcePermissionModal: setTriggerAddAPIResourcePermissionModal })))),
        triggerAddAPIResourcePermissionModal && (React__default.createElement(AddAPIResourcePermission, { closeWizard: () => setTriggerAddAPIResourcePermissionModal(), handleUpdateAPIResource: handleUpdateAPIResource })),
        deletingAPIResourcePermission && (React__default.createElement(ConfirmationModal, { primaryActionLoading: isSubmitting, open: deletingAPIResourcePermission !== null, onClose: () => setDeletingAPIResourcePermission(null), type: "negative", assertionHint: t("apiResources:confirmations." +
                "deleteAPIResourcePermission.assertionHint"), assertionType: "checkbox", primaryAction: t("common:confirm"), secondaryAction: t("common:cancel"), onSecondaryActionClick: () => setDeletingAPIResourcePermission(null), onPrimaryActionClick: () => deletePermission(), "data-testid": `${componentId}-delete-confirmation-modal`, closeOnDimmerClick: false },
            React__default.createElement(ConfirmationModal.Header, { "data-testid": `${componentId}-delete-confirmation-modal-header` }, t("apiResources:confirmations.deleteAPIResourcePermission." +
                "header")),
            React__default.createElement(ConfirmationModal.Message, { attached: true, negative: true, "data-testid": `${componentId}-delete-confirmation-modal-message` }, t("apiResources:confirmations.deleteAPIResourcePermission." +
                "message")),
            React__default.createElement(ConfirmationModal.Content, { "data-testid": `${componentId}-delete-confirmation-modal-content` }, t("apiResources:confirmations.deleteAPIResourcePermission." +
                "content"))))));
};
/**
 * Default props for the component.
 */
PermissionAPIResource.defaultProps = {
    "data-componentid": "permission-api-resource"
};

export { PermissionAPIResource };
