import { __awaiter } from '../../node_modules/.pnpm/tslib@2.6.2/node_modules/tslib/tslib.es6.js';
import { CommonUtils } from '@thiva/core/utils';
import { DataTable, EmptyPlaceholder, PrimaryButton, LinkButton } from '@thiva/react-components';
import React__default, { useState } from 'react';
import Header from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Header/Header.js';
import Icon from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Icon/Icon.js';
import Label from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Label/Label.js';
import { getEmptyPlaceholderIllustrations } from '@thiva/admin.core.v1';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const PermissionListAPIResource = (props) => {
    const { permissionList, serachedPermissionList, isAPIResourceDataLoading, isSubmitting, isReadOnly, clearSearchPermission, setRemovePermission, setTriggerAddAPIResourcePermissionModal, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const [clickedPermission, setClickedPermission] = useState(undefined);
    /**
     * Resolves data table actions.
     *
     * @returns `TableActionsInterface[]`
     */
    const resolveTableActions = () => {
        const actions = [
            {
                "data-componentid": `${componentId}-item-copy-button`,
                icon: () => "copy",
                onClick: (e, permission) => {
                    copyValueToClipboard(e, permission);
                },
                popupText: (permission) => {
                    return (clickedPermission === null || clickedPermission === void 0 ? void 0 : clickedPermission.name) === permission.name
                        ? t("apiResources:tabs.scopes.copiedPopupText")
                        : t("apiResources:tabs.scopes.copyPopupText");
                },
                renderer: "semantic-icon"
            },
            {
                "data-componentid": `${componentId}-item-delete-button`,
                hidden: () => isReadOnly,
                icon: () => "trash alternate",
                onClick: (e, permission) => {
                    removePermission(permission);
                },
                popupText: () => t("apiResources:tabs.scopes.removeScopePopupText"),
                renderer: "semantic-icon"
            }
        ];
        return actions;
    };
    /**
     * Resolves data table columns.
     * First column is the permission name and the second column is the description.
     *
     * @returns `TableColumnInterface[]`
     */
    const resolveTableColumns = () => {
        return [
            {
                allowToggleVisibility: false,
                dataIndex: "displayName",
                id: "displayName",
                key: "displayName",
                render: (permission) => (React__default.createElement(Header, { as: "h6", "data-testid": `${componentId}-permission-display-name` },
                    React__default.createElement(Header.Content, null,
                        permission.displayName,
                        React__default.createElement(Header.Subheader, null,
                            React__default.createElement(Label, { size: "medium", className: "ml-0 mt-2" },
                                React__default.createElement(Label.Detail, { className: "ml-0" }, permission.name)))))),
                title: t("extensions:develop.apiResource.tabs.permissions.form.fields.permission.label"),
                width: 3
            },
            {
                allowToggleVisibility: false,
                dataIndex: "description",
                id: "description",
                key: "description",
                render: (permission) => (React__default.createElement(Header, { as: "h6", "data-testid": `${componentId}-description` },
                    React__default.createElement(Header.Content, null,
                        React__default.createElement(Header.Subheader, null, permission.description)))),
                title: t("extensions:develop.apiResource.tabs.permissions.form.fields.description.label")
            },
            {
                allowToggleVisibility: false,
                dataIndex: "action",
                id: "actions",
                key: "actions",
                textAlign: "right",
                title: t("extensions:develop.apiResource.tabs.permissions.form.fields.permission.label")
            }
        ];
    };
    /**
     * Empty placeholder for the API resource permissions list.
     *
     * @returns `ReactElement`
     */
    const showPlaceholders = () => {
        if ((permissionList === null || permissionList === void 0 ? void 0 : permissionList.length) === 0) {
            return (React__default.createElement(EmptyPlaceholder, { subtitle: [t("apiResources:tabs.scopes.empty.subTitle")], title: t("apiResources:tabs.scopes.empty.title"), image: getEmptyPlaceholderIllustrations().emptyList, action: (React__default.createElement(PrimaryButton, { "data-componentid": `${componentId}-add-permission-button`, onClick: setTriggerAddAPIResourcePermissionModal },
                    React__default.createElement(Icon, { name: "add" }),
                    t("apiResources:tabs.scopes.button"))), imageSize: "tiny" }));
        }
        if ((serachedPermissionList === null || serachedPermissionList === void 0 ? void 0 : serachedPermissionList.length) === 0) {
            return (React__default.createElement(EmptyPlaceholder, { subtitle: [t("apiResources:tabs.scopes.emptySearch.subTitle.0"),
                    t("apiResources:tabs.scopes.emptySearch.subTitle.1")], title: t("apiResources:tabs.scopes.emptySearch.title"), image: getEmptyPlaceholderIllustrations().emptySearch, action: (React__default.createElement(LinkButton, { onClick: clearSearchPermission }, t("apiResources:tabs.scopes.emptySearch.viewAll"))), imageSize: "tiny" }));
        }
        return null;
    };
    /**
     * Handels the remove permission action.
     *
     * @param permission - `APIResourcePermissionInterface`
     */
    const removePermission = (permission) => {
        setRemovePermission(permission);
    };
    /**
     * Copies the value to the users clipboard.
     *
     * @param event - `MouseEvent<HTMLButtonElement>`
     * @param permission - `APIResourcePermissionInterface`
     */
    const copyValueToClipboard = (event, permission) => __awaiter(void 0, void 0, void 0, function* () {
        event.stopPropagation();
        yield CommonUtils.copyTextToClipboard(permission.name);
        // Set the clicked permission.
        setClickedPermission(permission);
    });
    return (React__default.createElement(DataTable, { className: "oidc-scopes-table", columnCount: 3, isLoading: isAPIResourceDataLoading || isSubmitting, loadingStateOptions: {
            count: 10,
            imageType: "square"
        }, onRowClick: copyValueToClipboard, showHeader: false, placeholders: showPlaceholders(), transparent: (permissionList === null || permissionList === void 0 ? void 0 : permissionList.length) === 0 || (serachedPermissionList === null || serachedPermissionList === void 0 ? void 0 : serachedPermissionList.length) === 0, "data-testid": componentId, actions: resolveTableActions(), columns: resolveTableColumns(), data: serachedPermissionList }));
};
/**
 * Default props for the component.
 */
PermissionListAPIResource.defaultProps = {
    "data-componentid": "permission-list-api-resource"
};

export { PermissionListAPIResource };
