import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { DataTable, ConfirmationModal, AppAvatar, AnimatedAvatar, EmptyPlaceholder, LinkButton, PrimaryButton } from '@thiva/react-components';
import React__default, { useState } from 'react';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import Header from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Header/Header.js';
import Icon from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Icon/Icon.js';
import Label from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Label/Label.js';
import { UIConstants, getEmptyPlaceholderIllustrations, history } from '@thiva/admin.core.v1';
import { deleteAPIResource } from '../api/api-resources.js';
import { APIResourcesConstants } from '../constants/api-resources-constants.js';
import { APIResourceUtils } from '../utils/api-resource-utils.js';
import { useTranslation } from '../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/components/Provider.js';
import '../node_modules/.pnpm/hoist-non-react-statics@3.3.2/node_modules/hoist-non-react-statics/dist/hoist-non-react-statics.cjs.js';
import '../node_modules/.pnpm/react-is@17.0.2/node_modules/react-is/index.js';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/components/Context.js';
import { useSelector } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * Users info page.
 *
 * @returns The users list table.
 */
const APIResourcesList = (props) => {
    const { apiResourcesList, categoryId, featureConfig, isAPIResourcesListLoading, onAPIResourceDelete, onListItemClick, onSearchQueryClear, searchQuery, showListItemActions, onEmptyListPlaceholderActionClicked, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    const [loading, setLoading] = useState(false);
    const [showDeleteConfirmationModal, setShowDeleteConfirmationModal] = useState(false);
    const [deletingAPIResource, setDeletingAPIResource] = useState(undefined);
    const allowedScopes = useSelector((state) => { var _a; return (_a = state === null || state === void 0 ? void 0 : state.auth) === null || _a === void 0 ? void 0 : _a.allowedScopes; });
    /**
     * Resolves data table columns.
     *
     * @returns TableColumnInterface[]
     */
    const resolveTableColumns = () => {
        return [
            {
                allowToggleVisibility: false,
                dataIndex: "name",
                id: "name",
                key: "name",
                render: (apiResource) => {
                    const displayName = apiResource ? apiResource.name : "";
                    let shownName;
                    if (displayName && displayName !== "") {
                        shownName = displayName;
                    }
                    else {
                        shownName = "";
                    }
                    return (React__default.createElement(Header, { as: "h6", className: "header-with-icon", "data-testid": `${componentId}-item-heading` },
                        React__default.createElement(AppAvatar, { image: (React__default.createElement(AnimatedAvatar, { name: shownName, size: "mini", "data-testid": `${componentId}-item-display-name-avatar` })), size: "mini", spaced: "right", "data-testid": `${componentId}-item-display-name` }),
                        React__default.createElement(Header.Content, null,
                            shownName,
                            React__default.createElement(Header.Subheader, null, APIResourceUtils.checkIfAPIResourcePropertyManaged(apiResource.properties) && (React__default.createElement(Label, { size: "mini", className: "choreo-label ml-0" }, t("extensions:develop.apiResource.managedByChoreoText")))))));
                },
                title: t("extensions:develop.apiResource.table.name.column")
            },
            {
                allowToggleVisibility: false,
                dataIndex: "identifier",
                id: "identifier",
                key: "identifier",
                render: (apiResource) => {
                    const identifier = apiResource ? apiResource.identifier : "";
                    let shownIdentifier = "";
                    const shownIdentifierClass = "client-id-label";
                    if (identifier && identifier !== "") {
                        shownIdentifier = identifier;
                    }
                    return (React__default.createElement(Header, { as: "h6", "data-testid": `${componentId}-col-2-item-heading` },
                        React__default.createElement(Header.Content, null,
                            React__default.createElement(Header.Subheader, { "data-testid": `${componentId}-col-2-item-sub-heading` },
                                shownIdentifier,
                                shownIdentifier && (React__default.createElement(Label, { pointing: "left", size: "mini", className: shownIdentifierClass }, t("extensions:develop.apiResource.table.identifier.label")))))));
                },
                title: t("extensions:develop.apiResource.table.identifier.column")
            },
            {
                allowToggleVisibility: false,
                dataIndex: "action",
                id: "actions",
                key: "actions",
                textAlign: "right",
                title: t("extensions:develop.apiResource.table.actions.column")
            }
        ];
    };
    /**
     * Resolves data table actions.
     *
     * @returns TableActionsInterface[]
     */
    const resolveTableActions = () => {
        if (!showListItemActions) {
            return;
        }
        return [
            {
                "data-componentid": `${componentId}-item-edit-button`,
                hidden: () => {
                    const readForbidden = !APIResourceUtils.isAPIResourceReadAllowed(featureConfig, allowedScopes);
                    const updateForbidden = !APIResourceUtils.isAPIResourceUpdateAllowed(featureConfig, allowedScopes);
                    return readForbidden && updateForbidden;
                },
                icon: (apiResource) => {
                    const updateAllowed = APIResourceUtils.isAPIResourceUpdateAllowed(featureConfig, allowedScopes);
                    const isSystemAPIResource = APIResourceUtils.isSystemAPI(apiResource === null || apiResource === void 0 ? void 0 : apiResource.type);
                    const canUpdate = !isSystemAPIResource && updateAllowed;
                    return canUpdate ? "pencil alternate" : "eye";
                },
                onClick: (e, apiResource) => {
                    handleAPIResourceEdit(apiResource, e);
                },
                popupText: (apiResource) => {
                    const updateAllowed = APIResourceUtils.isAPIResourceUpdateAllowed(featureConfig, allowedScopes);
                    const isSystemAPIResource = APIResourceUtils.isSystemAPI(apiResource === null || apiResource === void 0 ? void 0 : apiResource.type);
                    const canUpdate = !isSystemAPIResource && updateAllowed;
                    return canUpdate ? t("common:edit") : t("common:view");
                },
                renderer: "semantic-icon"
            },
            {
                "data-componentid": `${componentId}-item-delete-button`,
                hidden: (apiResource) => {
                    const deleteForbidden = !APIResourceUtils.isAPIResourceDeleteAllowed(featureConfig, allowedScopes);
                    const isSystemAPIResource = APIResourceUtils.isSystemAPI(apiResource === null || apiResource === void 0 ? void 0 : apiResource.type);
                    return deleteForbidden || isSystemAPIResource;
                },
                icon: () => "trash alternate",
                onClick: (e, apiResource) => {
                    setShowDeleteConfirmationModal(true);
                    setDeletingAPIResource(apiResource);
                },
                popupText: () => t("common:delete"),
                renderer: "semantic-icon"
            }
        ];
    };
    /**
     * Resolve the relevant placeholder.
     *
     * @returns React element.
     */
    const showPlaceholders = () => {
        // When the search returns empty.
        if (searchQuery && (apiResourcesList && apiResourcesList.length === 0)) {
            return (React__default.createElement(EmptyPlaceholder, { action: (React__default.createElement(LinkButton, { onClick: onSearchQueryClear }, t("console:develop.placeholders.emptySearchResult.action"))), image: getEmptyPlaceholderIllustrations().emptySearch, imageSize: "tiny", title: t("console:develop.placeholders.emptySearchResult.title"), subtitle: [
                    t("console:develop.placeholders.emptySearchResult.subtitles.0", { query: searchQuery }),
                    t("console:develop.placeholders.emptySearchResult.subtitles.1")
                ], "data-testid": `${componentId}-empty-search-placeholder-icon` }));
        }
        if ((!apiResourcesList) || (apiResourcesList && apiResourcesList.length === 0)) {
            return (React__default.createElement(EmptyPlaceholder, { image: getEmptyPlaceholderIllustrations().emptyList, imageSize: "tiny", subtitle: [t("extensions:develop.apiResource.empty")], "data-testid": `${componentId}-empty-search-placeholder-icon`, action: APIResourceUtils.isAPIResourceCreateAllowed(featureConfig, allowedScopes) &&
                    onEmptyListPlaceholderActionClicked
                    ? (React__default.createElement(PrimaryButton, { onClick: () => onEmptyListPlaceholderActionClicked(), "data-testid": `${componentId}-add-api-resources-button` },
                        React__default.createElement(Icon, { name: "add" }),
                        t("extensions:develop.apiResource.addApiResourceButton"))) : null }));
        }
        return null;
    };
    /**
     * Deletes an API resource when the delete API resource button is clicked.
     *
     * @param apiResourceId - API resource ID.
     */
    const handleAPIResourceDelete = (apiResourceId) => {
        setLoading(true);
        deleteAPIResource(apiResourceId)
            .then(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.deleteAPIResource.success" +
                    ".description"),
                level: AlertLevels.SUCCESS,
                message: t("extensions:develop.apiResource.notifications.deleteAPIResource.success.message")
            }));
            setShowDeleteConfirmationModal(false);
            if (onAPIResourceDelete) {
                onAPIResourceDelete();
            }
        })
            .catch(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.deleteAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.deleteAPIResource" +
                    ".genericError.message")
            }));
        })
            .finally(() => {
            setLoading(false);
            setDeletingAPIResource(undefined);
        });
    };
    /**
     * Redirects to the API resource edit page
     *
     */
    const handleAPIResourceEdit = (apiResource, e) => {
        history.push(APIResourcesConstants.getPaths().get("API_RESOURCE_EDIT")
            .replace(":categoryId", categoryId)
            .replace(":id", apiResource.id));
        onListItemClick && onListItemClick(e, apiResource);
    };
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement(DataTable, { className: "api-resources-table", loadingStateOptions: {
                count: UIConstants.DEFAULT_RESOURCE_LIST_ITEM_LIMIT,
                imageType: "circular"
            }, showHeader: false, "data-componentid": componentId, "data-testid": componentId, columns: resolveTableColumns(), placeholders: showPlaceholders(), actions: resolveTableActions(), data: apiResourcesList, transparent: isAPIResourcesListLoading || showPlaceholders() !== null, isLoading: isAPIResourcesListLoading, onRowClick: function (e, apiResource) {
                handleAPIResourceEdit(apiResource, e);
            } }),
        deletingAPIResource && (React__default.createElement(ConfirmationModal, { primaryActionLoading: loading, onClose: () => setShowDeleteConfirmationModal(false), type: "negative", open: showDeleteConfirmationModal, assertionHint: t("extensions:develop.apiResource.confirmations.deleteAPIResource." +
                "assertionHint"), assertionType: "checkbox", primaryAction: t("common:confirm"), secondaryAction: t("common:cancel"), onSecondaryActionClick: () => {
                setShowDeleteConfirmationModal(false);
            }, onPrimaryActionClick: () => handleAPIResourceDelete(deletingAPIResource.id), "data-testid": `${componentId}-delete-confirmation-modal`, closeOnDimmerClick: false },
            React__default.createElement(ConfirmationModal.Header, { "data-testid": `${componentId}-delete-confirmation-modal-header` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.header")),
            React__default.createElement(ConfirmationModal.Message, { attached: true, negative: true, "data-testid": `${componentId}-delete-confirmation-modal-message` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.message")),
            React__default.createElement(ConfirmationModal.Content, { "data-testid": `${componentId}-delete-confirmation-modal-content` }, t("extensions:develop.apiResource.confirmations.deleteAPIResource.content"))))));
};
/**
 * Default props for the component.
 */
APIResourcesList.defaultProps = {
    "data-componentid": "api-resources",
    showListItemActions: true
};

export { APIResourcesList };
