import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { ResourceTab } from '@thiva/react-components';
import React__default, { useState } from 'react';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import { AuthorizationAPIResource } from './api-resource-panes/authorization-api-resource.js';
import { GeneralAPIResource } from './api-resource-panes/general-api-resource.js';
import { PermissionAPIResource } from './api-resource-panes/permission-api-resource.js';
import './api-resource-panes/permission-list-api-resource.js';
import { updateAPIResource, deleteScopeFromAPIResource } from '../api/api-resources.js';
import { useTranslation } from '../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const EditAPIResource = (props) => {
    const { featureConfig, isReadOnly, apiResourceData, isAPIResourceDataLoading, mutateAPIResource } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    const [isSubmitting, setIsSubmitting] = useState(false);
    /**
     * Panes for the resource tab.
     * @returns `ResourceTab.Pane[]`
     */
    const panes = () => ([
        {
            menuItem: t("extensions:develop.apiResource.tabs.general.label"),
            render: () => (React__default.createElement(ResourceTab.Pane, { controlledSegmentation: true, attached: false },
                React__default.createElement(GeneralAPIResource, { apiResourceData: apiResourceData, isAPIResourceDataLoading: isAPIResourceDataLoading, featureConfig: featureConfig, isReadOnly: isReadOnly, isSubmitting: isSubmitting, handleUpdateAPIResource: handleUpdateAPIResource })))
        },
        {
            menuItem: t("apiResources:tabs.scopes.label"),
            render: () => (React__default.createElement(ResourceTab.Pane, { controlledSegmentation: true, attached: false },
                React__default.createElement(PermissionAPIResource, { apiResourceData: apiResourceData, isAPIResourceDataLoading: isAPIResourceDataLoading, isSubmitting: isSubmitting, isReadOnly: isReadOnly, handleUpdateAPIResource: handleUpdateAPIResource, handleDeleteAPIScope: handleDeleteAPIScope })))
        },
        {
            menuItem: t("extensions:develop.apiResource.tabs.authorization.label"),
            render: () => (React__default.createElement(ResourceTab.Pane, { controlledSegmentation: true, attached: false },
                React__default.createElement(AuthorizationAPIResource, { apiResourceData: apiResourceData, isAPIResourceDataLoading: isAPIResourceDataLoading })))
        }
    ]);
    /**
     * Handles API Resource update actions.
     *
     * @param updatedDetails - Form values.
     * @param callback - Callback function to be executed after the update is completed.
     */
    const handleUpdateAPIResource = (updatedAPIResource, callback) => {
        setIsSubmitting(true);
        updateAPIResource(apiResourceData.id, updatedAPIResource)
            .then(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.updateAPIResource.success" +
                    ".description"),
                level: AlertLevels.SUCCESS,
                message: t("extensions:develop.apiResource.notifications.updateAPIResource.success.message")
            }));
            mutateAPIResource();
        })
            .catch(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.updateAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.updateAPIResource" +
                    ".genericError.message")
            }));
        })
            .finally(() => {
            setIsSubmitting(false);
            // Callback function to be executed after the update is completed.
            callback && callback();
        });
    };
    /**
     * Handles API scope delete action.
     *
     * @param deletingScopeName - Name of the scope that needs to be deleted.
     * @param callback - Callback function to be executed after the update is completed.
     */
    const handleDeleteAPIScope = (deletingScopeName, callback) => {
        setIsSubmitting(true);
        deleteScopeFromAPIResource(apiResourceData.id, deletingScopeName)
            .then(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.updateAPIResource.success" +
                    ".description"),
                level: AlertLevels.SUCCESS,
                message: t("extensions:develop.apiResource.notifications.updateAPIResource.success.message")
            }));
            mutateAPIResource();
        })
            .catch(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.updateAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.updateAPIResource" +
                    ".genericError.message")
            }));
        })
            .finally(() => {
            setIsSubmitting(false);
            // Callback function to be executed after the update is completed.
            callback && callback();
        });
    };
    return (React__default.createElement(ResourceTab, { isLoading: isAPIResourceDataLoading, panes: panes() }));
};

export { EditAPIResource };
