import { __awaiter } from '../../../node_modules/.pnpm/tslib@2.6.2/node_modules/tslib/tslib.es6.js';
import { Forms, Field } from '@thiva/forms';
import { Hint } from '@thiva/react-components';
import React__default from 'react';
import Grid from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/collections/Grid/Grid.js';
import { getAPIResourcePermissions } from '../../../api/api-resources.js';
import { APIResourcesConstants } from '../../../constants/api-resources-constants.js';
import { useTranslation } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { Trans } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/Trans.js';

/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const FORM_ID = "apiResource-general-details";
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const AddAPIResourcePermissionForm = (props) => {
    const { permissionValidationLoading, triggerAddPermission, addPermission, setIsSubmitting, setPermissionValidationLoading, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    /**
     * Prepare form values for submitting.
     *
     * @param values - Form values.
     * @returns Sanitized form values.
     */
    const submitAddPermission = (values) => {
        const permission = {
            description: values.get("description").toString(),
            displayName: values.get("displayName").toString(),
            name: values.get("identifier").toString()
        };
        setIsSubmitting(true);
        addPermission(permission);
    };
    return (React__default.createElement(Forms, { "data-componentid": `${componentId}-form`, onSubmit: submitAddPermission, id: FORM_ID, submitState: triggerAddPermission, uncontrolledForm: false },
        React__default.createElement(Grid, null,
            React__default.createElement(Grid.Row, { columns: 1 },
                React__default.createElement(Grid.Column, { mobile: 16, tablet: 16, computer: 12 },
                    React__default.createElement(Field, { type: "text", name: "identifier", label: t("apiResources:tabs.scopes.form.fields.scope.label"), placeholder: t("apiResources:tabs.scopes.form.fields." +
                            "scope.placeholder"), required: true, tabIndex: 1, requiredErrorMessage: t("apiResources:wizard.addApiResource.steps." +
                            "scopes.form.fields.permission.emptyValidate"), validation: (value, validation) => __awaiter(void 0, void 0, void 0, function* () {
                            setPermissionValidationLoading(true);
                            if (value) {
                                if (!APIResourcesConstants.checkValidPermissionIdentifier(value)) {
                                    validation.isValid = false;
                                    validation.errorMessages.push(t("apiResources:wizard." +
                                        "addApiResource.steps.scopes.form.fields.permission.invalid"));
                                }
                                else {
                                    const filter = "name eq " + value;
                                    const response = yield getAPIResourcePermissions(filter);
                                    if ((response === null || response === void 0 ? void 0 : response.length) > 0) {
                                        validation.isValid = false;
                                        validation.errorMessages.push(t("apiResources:wizard." +
                                            "addApiResource.steps.scopes.form.fields.permission.uniqueValidate"));
                                    }
                                }
                                setPermissionValidationLoading(false);
                            }
                        }), "data-testid": `${componentId}-identifier`, loading: permissionValidationLoading }),
                    React__default.createElement(Hint, null,
                        React__default.createElement(Trans, { i18nKey: "apiResources:wizard.addApiResource.steps." +
                                "scopes.form.fields.scope.hint" },
                            "A unique value that acts as the scope when requesting an access token.\u00A0",
                            React__default.createElement("b", null, "Note that the scope cannot be modified once created."))))),
            React__default.createElement(Grid.Row, { columns: 1 },
                React__default.createElement(Grid.Column, { mobile: 16, tablet: 16, computer: 12 },
                    React__default.createElement(Field, { type: "text", name: "displayName", label: t("extensions:develop.apiResource.tabs.permissions.form.fields.displayName.label"), placeholder: t("extensions:develop.apiResource.tabs.permissions.form.fields." +
                            "displayName.placeholder"), required: true, tabIndex: 2, requiredErrorMessage: t("extensions:develop.apiResource.tabs.permissions.form.fields." +
                            "displayName.emptyValidate"), "data-testid": `${componentId}-displayName` }),
                    React__default.createElement(Hint, null, t("extensions:develop.apiResource.wizard.addApiResource.steps." +
                        "permissions.form.fields.displayName.hint")))),
            React__default.createElement(Grid.Row, { columns: 1 },
                React__default.createElement(Grid.Column, { mobile: 16, tablet: 16, computer: 12 },
                    React__default.createElement(Field, { type: "text", name: "description", label: t("apiResources:tabs.scopes.form.fields.description.label"), placeholder: t("apiResources:tabs.scopes.form.fields." +
                            "description.placeholder"), tabIndex: 3, "data-testid": `${componentId}-description` }),
                    React__default.createElement(Hint, null, t("apiResources:wizard.addApiResource.steps." +
                        "scopes.form.fields.description.hint")))))));
};
/**
 * Default props for the component.
 */
AddAPIResourcePermissionForm.defaultProps = {
    "data-componentid": "add-api-resource-permission-form"
};

export { AddAPIResourcePermissionForm };
