import { useTrigger } from '@thiva/forms';
import { Heading, LinkButton, PrimaryButton } from '@thiva/react-components';
import React__default, { useState } from 'react';
import Grid from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/collections/Grid/Grid.js';
import Modal from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/modules/Modal/Modal.js';
import { AddAPIResourcePermissionForm } from './add-api-resource-permission-components/add-api-resource-permission-form.js';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API resource wizard.
 */
const AddAPIResourcePermission = (props) => {
    const { closeWizard, handleUpdateAPIResource, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const [submitAddPermissionForm, setSubmitAddPermissionForm] = useTrigger();
    const [isSubmitting, setIsSubmitting] = useState(false);
    const [permissionValidationLoading, setPermissionValidationLoading] = useState(false);
    const addPermission = (permission) => {
        handleUpdateAPIResource({
            addedScopes: [permission]
        }, () => {
            closeWizard();
            setIsSubmitting(false);
        });
    };
    return (React__default.createElement(Modal, { "data-testid": componentId, open: true, className: "wizard api-resource-permission-create-wizard", dimmer: "blurring", size: "small", onClose: closeWizard, closeOnDimmerClick: false, closeOnEscape: true },
        React__default.createElement(Modal.Header, { className: "wizard-header" },
            t("apiResources:tabs.scopes.form.title"),
            React__default.createElement(Heading, { as: "h6" }, t("apiResources:tabs.scopes.form.subTitle"))),
        React__default.createElement(Modal.Content, { className: "content-container" },
            React__default.createElement(AddAPIResourcePermissionForm, { triggerAddPermission: submitAddPermissionForm, addPermission: addPermission, setIsSubmitting: setIsSubmitting, permissionValidationLoading: permissionValidationLoading, setPermissionValidationLoading: setPermissionValidationLoading })),
        React__default.createElement(Modal.Actions, null,
            React__default.createElement(Grid, null,
                React__default.createElement(Grid.Row, { column: 1 },
                    React__default.createElement(Grid.Column, { mobile: 8, tablet: 8, computer: 8 },
                        React__default.createElement(LinkButton, { "data-testid": `${componentId}-cancel-button`, floated: "left", onClick: () => closeWizard() }, t("apiResources:tabs.scopes.form.cancelButton"))),
                    React__default.createElement(Grid.Column, { mobile: 8, tablet: 8, computer: 8 },
                        React__default.createElement(PrimaryButton, { "data-testid": `${componentId}-finish-button`, floated: "right", onClick: () => setSubmitAddPermissionForm(), loading: isSubmitting }, t("apiResources:tabs.scopes.form.submitButton"))))))));
};
/**
 * Default props for the add API resource wizard.
 */
AddAPIResourcePermission.defaultProps = {
    "data-componentid": "add-api-resource-permission"
};

export { AddAPIResourcePermission };
