import { Form, Field } from '@thiva/form';
import { useDocumentation, Message, DocumentationLink } from '@thiva/react-components';
import React__default from 'react';
import '../../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import { useTranslation } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { Trans } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/Trans.js';
import { useSelector } from '../../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const FORM_ID = "apiResource-authorization";
/**
 * Add API Resource authorization component.
 *
 * @param props - Props injected to the component.
 * @returns Add API Resource authorization component
 */
const AddAPIResourceAuthorization = (props) => {
    const { triggerSubmission, initalRequiredAuthorizationValue, setRequiredAuthorization, submitCallback, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const { getLink } = useDocumentation();
    const productName = useSelector((state) => state.config.ui.productName);
    /**
     * Prepare form values for submitting.
     *
     * @param values - Form values.
     */
    const submitAuthorization = (values) => {
        setRequiredAuthorization(values.authorization);
        submitCallback && submitCallback(values.authorization);
    };
    return (React__default.createElement(Form, { "data-testid": `${componentId}-form`, onSubmit: submitAuthorization, triggerSubmit: (submitFunction) => triggerSubmission(submitFunction), id: FORM_ID, uncontrolledForm: false },
        React__default.createElement(Message, { type: "info", content: (React__default.createElement(React__default.Fragment, null,
                t("extensions:develop.apiResource.wizard.addApiResource.steps.authorization.form." +
                    "rbacMessage", { productName }),
                React__default.createElement(DocumentationLink, { link: getLink("develop.apiResources.addAPIResource.rbacInfoBox.learnMore") }, t("extensions:common.learnMore")))) }),
        React__default.createElement(Field.Checkbox, { ariaLabel: "authorization", name: "authorization", label: t("extensions:develop.apiResource.wizard.addApiResource.steps.authorization.form.fields." +
                "authorize.label"), tabIndex: 3, hint: (React__default.createElement(React__default.Fragment, null,
                React__default.createElement(Trans, { i18nKey: "extensions:develop.apiResource.wizard.addApiResource.steps.authorization." +
                        "form.fields.authorize.hint" },
                    "If checked, it will be mandatory to add authorization when configuring the application to consume the API resource. ",
                    React__default.createElement("b", null, "This field cannot be edited once created.")),
                React__default.createElement(DocumentationLink, { link: getLink("develop.apiResources.addAPIResource.requiredAuthorization.learnMore") }, t("extensions:common.learnMore")))), width: 16, defaultValue: initalRequiredAuthorizationValue, "data-componentid": `${componentId}-authorize` })));
};
/**
 * Default props for the component.
 */
AddAPIResourceAuthorization.defaultProps = {
    "data-componentid": "add-api-resource-authorizaiton"
};

export { AddAPIResourceAuthorization };
