import { __awaiter } from '../../../node_modules/.pnpm/tslib@2.6.2/node_modules/tslib/tslib.es6.js';
import { Forms, Field } from '@thiva/forms';
import { Hint } from '@thiva/react-components';
import React__default, { useRef } from 'react';
import '../../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import Grid from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/collections/Grid/Grid.js';
import { getAPIResourcesForIdenitifierValidation } from '../../../api/api-resources.js';
import { APIResourcesConstants } from '../../../constants/api-resources-constants.js';
import { useTranslation } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { Trans } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/Trans.js';
import { useSelector } from '../../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const AddAPIResourceBasic = (props) => {
    const { triggerSubmission, initalBasicDetails, setBasicDetails, submitCallback, isIdentifierValidationLoading, setIdentifierValidationLoading, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const identifierRef = useRef();
    const productName = useSelector((state) => state.config.ui.productName);
    /**
     * Prepare form values for submitting.
     *
     * @param values - Form values.
     */
    const submitBasicDetails = (values) => {
        setBasicDetails({
            displayName: values.get("displayName").toString(),
            identifier: values.get("identifier").toString()
        });
        submitCallback && submitCallback();
    };
    return (React__default.createElement(Forms, { "data-testid": `${componentId}-form`, onSubmit: submitBasicDetails, submitState: triggerSubmission },
        React__default.createElement(Grid, null,
            React__default.createElement(Grid.Row, { columns: 1 },
                React__default.createElement(Grid.Column, { mobile: 16, tablet: 16, computer: 12 },
                    React__default.createElement(Field, { ref: identifierRef, type: "text", name: "identifier", label: t("extensions:develop.apiResource.wizard.addApiResource.steps.basic.form." +
                            "fields.identifier.label"), placeholder: t("extensions:develop.apiResource.wizard.addApiResource.steps.basic." +
                            "form.fields.identifier.placeholder"), requiredErrorMessage: t("extensions:develop.apiResource.wizard.addApiResource.steps." +
                            "basic.form.fields.identifier.emptyValidate"), required: true, tabIndex: 1, value: initalBasicDetails && initalBasicDetails.identifier, validation: (value, validation) => __awaiter(void 0, void 0, void 0, function* () {
                            var _a;
                            setIdentifierValidationLoading(true);
                            if (!APIResourcesConstants.checkValidPermissionIdentifier(value)) {
                                validation.isValid = false;
                                validation.errorMessages.push(t("extensions:develop.apiResource.wizard." +
                                    "addApiResource.steps.basic.form.fields.identifier.invalid"));
                            }
                            else {
                                const filter = "identifier eq " + value;
                                const response = yield getAPIResourcesForIdenitifierValidation(filter);
                                if (((_a = response === null || response === void 0 ? void 0 : response.apiResources) === null || _a === void 0 ? void 0 : _a.length) > 0) {
                                    validation.isValid = false;
                                    validation.errorMessages.push(t("extensions:develop.apiResource.wizard." +
                                        "addApiResource.steps.basic.form.fields.identifier.alreadyExistsError"));
                                }
                            }
                            setIdentifierValidationLoading(false);
                        }), "data-testid": `${componentId}-basic-form-identifier`, loading: isIdentifierValidationLoading }),
                    React__default.createElement(Hint, { className: "mb-0" },
                        React__default.createElement(Trans, { i18nKey: "extensions:develop.apiResource.wizard.addApiResource.steps.basic." +
                                "form.fields.identifier.hint", tOptions: { productName } },
                            "We recommend using a URI as the identifier, but you do not need to make the URI publicly available since WSO2 Identity Server will not access your API. WSO2 Identity Server will use this identifier value as the audience(aud) claim in the issued JWT tokens. ",
                            React__default.createElement("b", null, "This field should be unique; once created, it is not editable."))))),
            React__default.createElement(Grid.Row, { columns: 1 },
                React__default.createElement(Grid.Column, { mobile: 16, tablet: 16, computer: 12 },
                    React__default.createElement(Field, { type: "text", name: "displayName", label: t("extensions:develop.apiResource.wizard.addApiResource.steps.basic.form.fields." +
                            "name.label"), placeholder: t("extensions:develop.apiResource.wizard.addApiResource.steps.basic.form." +
                            "fields.name.placeholder"), required: true, tabIndex: 2, requiredErrorMessage: t("extensions:develop.apiResource.wizard.addApiResource.steps." +
                            "basic.form.fields.name.emptyValidate"), value: initalBasicDetails === null || initalBasicDetails === void 0 ? void 0 : initalBasicDetails.displayName, "data-testid": `${componentId}-basic-form-displayName` }),
                    React__default.createElement(Hint, { className: "mb-0" }, t("extensions:develop.apiResource.wizard.addApiResource.steps.basic.form.fields." +
                        "name.hint", { productName })))))));
};
/**
 * Default props for the component.
 */
AddAPIResourceBasic.defaultProps = {
    "data-componentid": "add-api-resource-basic"
};

export { AddAPIResourceBasic };
