import { EmphasizedSegment } from '@thiva/react-components';
import React__default, { useState, useEffect } from 'react';
import Grid from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/collections/Grid/Grid.js';
import Header from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Header/Header.js';
import { PermissionMappingList } from './permission-mapping-list.js';
import { PermissionMappingListItem } from './permission-mapping-list-item.js';
import { useTranslation } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const AddAPIResourcePermissions = (props) => {
    const { initialPermissions, triggerAddPermission, isPermissionValidationLoading, setAddPermission, setPermissionsList, setLatestPermissionFormValues, setPermissionValidationLoading } = props;
    const { t } = useTranslation();
    const [addedPermissions, setAddedPermissions] = useState(initialPermissions ? initialPermissions : new Map());
    /**
     * Update the permission list when the added permissions map is updated.
     */
    useEffect(() => {
        setPermissionsList(addedPermissions);
    }, [addedPermissions]);
    /**
     * Update the permission map when a new permission is added or deleted.
     *
     * @param permission - The permission to be added or deleted.  `APIResourcePermissionInterface`
     * @param action - The action to be performed. `set` or `delete`
     */
    const updatePermissions = (permission, action) => {
        const updatedPermissions = new Map(addedPermissions);
        switch (action) {
            case "set":
                updatedPermissions.set(permission.name, permission);
                break;
            case "delete":
                updatedPermissions.delete(permission.name);
                break;
        }
        setAddedPermissions(updatedPermissions);
    };
    return (React__default.createElement(Grid, null,
        React__default.createElement(Grid.Row, { columns: 1 },
            React__default.createElement(Grid.Column, { width: 16 },
                React__default.createElement(EmphasizedSegment, { className: "mb-4" },
                    React__default.createElement(PermissionMappingListItem, { addedPermissions: addedPermissions, updatePermissions: updatePermissions, triggerAddPermission: triggerAddPermission, setAddPermission: setAddPermission, setLatestPermissionFormValues: setLatestPermissionFormValues, isPermissionValidationLoading: isPermissionValidationLoading, setPermissionValidationLoading: setPermissionValidationLoading }))),
            React__default.createElement(Grid.Column, { width: 16 },
                React__default.createElement(React__default.Fragment, null,
                    React__default.createElement(Header, { as: "h5", className: "bold-text mb-2" }, t("apiResources:wizard.addApiResource.steps.scopes.form." +
                        "fields.permissionList.label")),
                    React__default.createElement(EmphasizedSegment, { className: "mt-0" },
                        React__default.createElement(PermissionMappingList, { addedPermissions: addedPermissions, updatePermissions: updatePermissions })))))));
};

export { AddAPIResourcePermissions };
