import { DataTable, EmptyPlaceholder } from '@thiva/react-components';
import React__default, { useState, useEffect } from 'react';
import Divider from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Divider/Divider.js';
import Header from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Header/Header.js';
import Label from '../../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Label/Label.js';
import { useTranslation } from '../../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';

/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const PermissionMappingList = (props) => {
    const { addedPermissions, updatePermissions, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const [permissionsList, setPermissionsList] = useState(null);
    /**
     * Set the added permissions to the state.
     */
    useEffect(() => {
        setPermissionsList([...addedPermissions.values()].reverse());
    }, [addedPermissions]);
    /**
     * Resolves data table actions.
     *
     * @returns `TableActionsInterface[]`
     */
    const resolveTableActions = () => {
        const actions = [
            {
                icon: () => "trash alternate",
                onClick: (e, permission) => {
                    removeAddedPermission(permission);
                },
                popupText: () => t("apiResources:tabs.scopes.removeScopePopupText"),
                renderer: "semantic-icon"
            }
        ];
        return actions;
    };
    /**
     * Resolves data table columns.
     * First column is the permission name and the second column is the description.
     *
     * @returns `TableColumnInterface[]`
     */
    const resolveTableColumns = () => {
        return [
            {
                allowToggleVisibility: false,
                dataIndex: "displayName",
                id: "displayName",
                key: "displayName",
                render: (permission) => (React__default.createElement(Header, { as: "h6", "data-testid": `${componentId}-permission-display-name` },
                    React__default.createElement(Header.Content, null,
                        permission.displayName,
                        React__default.createElement(Header.Subheader, null,
                            React__default.createElement(Label, { size: "medium", className: "ml-0 mt-2" }, permission.name))))),
                title: t("apiResources:tabs.scopes.form.fields.permission.label")
            },
            {
                allowToggleVisibility: false,
                dataIndex: "description",
                id: "description",
                key: "description",
                render: (permission) => (React__default.createElement(Header, { as: "h6", "data-testid": `${componentId}-description` },
                    React__default.createElement(Header.Content, null,
                        React__default.createElement(Header.Subheader, null, permission.description)))),
                title: t("apiResources:tabs.scopes.form.fields.description.label")
            },
            {
                allowToggleVisibility: false,
                dataIndex: "action",
                id: "actions",
                key: "actions",
                textAlign: "right",
                title: t("apiResources:tabs.scopes.form.fields.permission.label"),
                width: 1
            }
        ];
    };
    /**
     * Empty placeholder for the permissions list.
     *
     * @returns `ReactElement`
     */
    const showPlaceholders = () => {
        if ((permissionsList === null || permissionsList === void 0 ? void 0 : permissionsList.length) === 0) {
            return (React__default.createElement(React__default.Fragment, null,
                React__default.createElement(Divider, { className: "mb-1", hidden: true }),
                React__default.createElement(EmptyPlaceholder, { subtitle: [t("apiResources:tabs.scopes.empty.title")] }),
                React__default.createElement(Divider, { className: "mt-1", hidden: true })));
        }
        return null;
    };
    /**
     * Handles the remove permission action.
     *
     * @param permission - `APIResourcePermissionInterface`
     */
    const removeAddedPermission = (permission) => {
        updatePermissions(permission, "delete");
    };
    return (React__default.createElement(DataTable, { className: "oidc-scopes-table", columnCount: 3, loadingStateOptions: {
            count: 10,
            imageType: "square"
        }, onRowClick: () => null, showHeader: false, placeholders: showPlaceholders(), transparent: (permissionsList === null || permissionsList === void 0 ? void 0 : permissionsList.length) === 0, "data-testid": componentId, actions: resolveTableActions(), columns: resolveTableColumns(), data: permissionsList }));
};
/**
 * Default props for the component.
 */
PermissionMappingList.defaultProps = {
    "data-componentid": "permission-list-api-resource"
};

export { PermissionMappingList };
