import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { useTrigger } from '@thiva/forms';
import { Heading, Steps, LinkButton, PrimaryButton } from '@thiva/react-components';
import React__default, { useState } from 'react';
import '../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import Grid from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/collections/Grid/Grid.js';
import Icon from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Icon/Icon.js';
import Modal from '../../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/modules/Modal/Modal.js';
import { AddAPIResourceAuthorization } from './add-api-resource-steps/add-api-resource-authorization.js';
import { AddAPIResourceBasic } from './add-api-resource-steps/add-api-resource-basic.js';
import { AddAPIResourcePermissions } from './add-api-resource-steps/add-api-resource-permissions.js';
import './add-api-resource-steps/permission-mapping-list-item.js';
import './add-api-resource-steps/permission-mapping-list.js';
import { history } from '@thiva/admin.core.v1';
import { createAPIResource } from '../../api/api-resources.js';
import { getAPIResourceWizardStepIcons } from '../../configs/ui.js';
import { APIResourcesConstants } from '../../constants/api-resources-constants.js';
import { AddAPIResourceWizardStepsFormTypes } from '../../models/api-resources.js';
import { useTranslation } from '../../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API resource wizard.
 */
const AddAPIResource = (props) => {
    const { closeWizard, currentStep, lastStepFormType, ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    //External trigger to submit the authorization step.
    let submitAuthorization;
    const [submitBasicDetails, setSubmitBasicDetails] = useTrigger();
    const [addPermission, setAddPermission] = useTrigger();
    const [isSubmitting, setIsSubmitting] = useState(false);
    const [latestPermissionFormValues, setLatestPermissionFormValues] = useState(undefined);
    const [basicDetails, setBasicDetails] = useState(undefined);
    const [requiredAuthorization, setRequiredAuthorization] = useState(true);
    const [permissions, setPermissions] = useState(new Map());
    const [currentWizardStep, setCurrentWizardStep] = useState(currentStep);
    const [currentWizardFormType, setCurrentWizardFormType] = useState(AddAPIResourceWizardStepsFormTypes.BASIC_DETAILS);
    const [isIdentifierValidationLoading, setIdentifierValidationLoading] = useState(false);
    const [isPermissionValidationLoading, setPermissionValidationLoading] = useState(false);
    /**
    * Handles the wizard form submission.
    */
    const handleWizardFormSubmit = () => {
        var _a, _b;
        switch (currentWizardFormType) {
            case AddAPIResourceWizardStepsFormTypes.BASIC_DETAILS:
                setSubmitBasicDetails();
                break;
            case AddAPIResourceWizardStepsFormTypes.PERMISSIONS: {
                if (((_a = latestPermissionFormValues === null || latestPermissionFormValues === void 0 ? void 0 : latestPermissionFormValues.get("displayName")) === null || _a === void 0 ? void 0 : _a.toString().trim()) !==
                    ((_b = latestPermissionFormValues === null || latestPermissionFormValues === void 0 ? void 0 : latestPermissionFormValues.get("identifier")) === null || _b === void 0 ? void 0 : _b.toString().trim())) {
                    setAddPermission();
                }
                handleNext();
                break;
            }
            case AddAPIResourceWizardStepsFormTypes.AUTHORIZATION:
                submitAuthorization();
                break;
        }
    };
    /**
     * Handles the next button click.
     */
    const handleNext = () => {
        const newStep = currentWizardStep + 1;
        setCurrentWizardStep(newStep);
        setCurrentWizardFormType(steps[newStep].addAPIResourceWizardStepsFormType);
    };
    /**
     * Handles the previous button click.
     */
    const handlePrevious = () => {
        const newStep = currentWizardStep - 1;
        setCurrentWizardStep(newStep);
        setCurrentWizardFormType(steps[newStep].addAPIResourceWizardStepsFormType);
    };
    /**
     * Handles the API resource creation.
     */
    const handleCreateAPIResource = (requiresAuthorization) => {
        setIsSubmitting(true);
        const apiResourceBody = {
            identifier: basicDetails.identifier,
            name: basicDetails.displayName,
            requiresAuthorization: requiresAuthorization,
            scopes: [...permissions.values()]
        };
        createAPIResource(apiResourceBody)
            .then((apiResource) => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.addAPIResource.success" +
                    ".description"),
                level: AlertLevels.SUCCESS,
                message: t("extensions:develop.apiResource.notifications.addAPIResource.success.message")
            }));
            // Open the created API resource.
            history.push(APIResourcesConstants.getPaths().get("API_RESOURCE_EDIT").replace(":id", apiResource.id));
        })
            .catch(() => {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.addAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.addAPIResource" +
                    ".genericError.message")
            }));
        })
            .finally(() => {
            setIsSubmitting(false);
            closeWizard();
        });
    };
    /**
     * Steps of the add API resource wizard.
     */
    const steps = [
        {
            addAPIResourceWizardStepsFormType: AddAPIResourceWizardStepsFormTypes.BASIC_DETAILS,
            content: (React__default.createElement(AddAPIResourceBasic, { initalBasicDetails: basicDetails, setBasicDetails: setBasicDetails, triggerSubmission: submitBasicDetails, submitCallback: handleNext, isIdentifierValidationLoading: isIdentifierValidationLoading, setIdentifierValidationLoading: setIdentifierValidationLoading })),
            icon: getAPIResourceWizardStepIcons().general,
            title: t("extensions:develop.apiResource.wizard.addApiResource.steps.basic.stepTitle")
        },
        {
            addAPIResourceWizardStepsFormType: AddAPIResourceWizardStepsFormTypes.PERMISSIONS,
            content: (React__default.createElement(AddAPIResourcePermissions, { setPermissionsList: setPermissions, initialPermissions: permissions, triggerAddPermission: addPermission, setAddPermission: setAddPermission, setLatestPermissionFormValues: setLatestPermissionFormValues, isPermissionValidationLoading: isPermissionValidationLoading, setPermissionValidationLoading: setPermissionValidationLoading })),
            icon: getAPIResourceWizardStepIcons().permissions,
            title: t("apiResources:wizard.addApiResource.steps.scopes.stepTitle")
        },
        {
            addAPIResourceWizardStepsFormType: AddAPIResourceWizardStepsFormTypes.AUTHORIZATION,
            content: (React__default.createElement(AddAPIResourceAuthorization, { triggerSubmission: (submitFunctionCb) => {
                    submitAuthorization = submitFunctionCb;
                }, initalRequiredAuthorizationValue: requiredAuthorization, setRequiredAuthorization: setRequiredAuthorization, submitCallback: handleCreateAPIResource })),
            icon: getAPIResourceWizardStepIcons().authorize,
            title: t("extensions:develop.apiResource.wizard.addApiResource.steps.authorization.stepTitle")
        }
    ];
    return (React__default.createElement(Modal, { "data-testid": componentId, open: true, className: "wizard api-resource-create-wizard", dimmer: "blurring", onClose: closeWizard, closeOnDimmerClick: false, closeOnEscape: true },
        React__default.createElement(Modal.Header, { className: "wizard-header" },
            t("extensions:develop.apiResource.wizard.addApiResource.title"),
            React__default.createElement(Heading, { as: "h6" }, t("extensions:develop.apiResource.wizard.addApiResource.subtitle"))),
        React__default.createElement(Modal.Content, { scrolling: true, className: "steps-container" },
            React__default.createElement(Steps.Group, { current: currentWizardStep }, steps.map((step) => (React__default.createElement(Steps.Step, { key: step.title, icon: step.icon, title: step.title }))))),
        React__default.createElement(Modal.Content, { className: "content-container", scrolling: true }, steps[currentWizardStep].content),
        React__default.createElement(Modal.Actions, null,
            React__default.createElement(Grid, null,
                React__default.createElement(Grid.Row, { column: 1 },
                    React__default.createElement(Grid.Column, { mobile: 8, tablet: 8, computer: 8 },
                        React__default.createElement(LinkButton, { tabIndex: 6, "data-testid": `${componentId}-cancel-button`, floated: "left", onClick: () => closeWizard() }, t("extensions:develop.apiResource.wizard.addApiResource.cancelButton"))),
                    React__default.createElement(Grid.Column, { mobile: 8, tablet: 8, computer: 8 },
                        currentWizardFormType !== lastStepFormType && (React__default.createElement(PrimaryButton, { tabIndex: 7, "data-testid": `${componentId}-next-button`, floated: "right", onClick: () => handleWizardFormSubmit(), loading: isIdentifierValidationLoading, disabled: isIdentifierValidationLoading },
                            t("extensions:develop.apiResource.wizard.addApiResource.nextButton"),
                            React__default.createElement(Icon, { name: "arrow right" }))),
                        currentWizardFormType === lastStepFormType && (React__default.createElement(PrimaryButton, { tabIndex: 8, "data-testid": `${componentId}-finish-button`, floated: "right", onClick: () => handleWizardFormSubmit(), loading: isSubmitting || isPermissionValidationLoading }, t("extensions:develop.apiResource.wizard.addApiResource.submitButton"))),
                        currentWizardStep > 0 && (React__default.createElement(LinkButton, { tabIndex: 9, "data-testid": `${componentId}-previous-button`, floated: "right", onClick: () => handlePrevious(), loading: isSubmitting },
                            React__default.createElement(Icon, { name: "arrow left" }),
                            t("extensions:develop.apiResource.wizard.addApiResource.previousButton")))))))));
};
/**
 * Default props for the add API resource wizard.
 */
AddAPIResource.defaultProps = {
    currentStep: 0,
    "data-componentid": "add-api-resource",
    lastStepFormType: AddAPIResourceWizardStepsFormTypes.AUTHORIZATION
};

export { AddAPIResource };
