import { AppConstants } from '@thiva/admin.core.v1';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * Class containing API resources constants.
 */
class APIResourcesConstants {
    /**
     * Private constructor to avoid object instantiation from outside
     * the class.
     *
     */
    constructor() { }
    /**
     * Get the API resource paths as a map.
     *
     * @returns `Map<string, string>`
     */
    static getPaths() {
        return new Map()
            .set("API_RESOURCES", `${AppConstants.getDeveloperViewBasePath()}/` + `${this.API_RESOURCE_DIR}`)
            .set("API_RESOURCES_CATEGORY", `${AppConstants.getDeveloperViewBasePath()}/${this.API_RESOURCE_DIR}/:categoryId`)
            .set("API_RESOURCE_EDIT", `${AppConstants.getDeveloperViewBasePath()}/${this.API_RESOURCE_DIR}/:categoryId/:id`);
    }
}
APIResourcesConstants.NEXT_REL = "next";
APIResourcesConstants.PREVIOUS_REL = "previous";
APIResourcesConstants.AFTER = "after";
APIResourcesConstants.BEFORE = "before";
APIResourcesConstants.DEFAULT_TOTAL_PAGES = 10;
APIResourcesConstants.API_RESOURCE_DIR = "api-resources";
// API Resource types.
APIResourcesConstants.SYSTEM = "SYSTEM";
APIResourcesConstants.SYSTEM_ORG = "SYSTEM_ORG";
APIResourcesConstants.SYSTEM_FEATURE = "SYSTEM_FEATURE";
APIResourcesConstants.BUSINESS = "BUSINESS";
// API Resource required attributes
APIResourcesConstants.PROPERTIES = "properties";
APIResourcesConstants.IS_CHOREO_API = "isChoreoAPI";
/**
 * To check whether the given value is a valid permission identifier.
 *
 * @param value - permission identifier
 * @returns boolean - true if the value is a valid permission identifier
 */
APIResourcesConstants.checkValidPermissionIdentifier = (value) => value.match(/\s/) === null;
/*
* The types of API Resources.
*/
var APIResourceType;
(function (APIResourceType) {
    APIResourceType["MANAGEMENT"] = "management";
    APIResourceType["ORGANIZATION"] = "organization";
    APIResourceType["BUSINESS"] = "business";
})(APIResourceType || (APIResourceType = {}));
/*
* The API Resource category type prefix.
* Manamgement API Resources are prefixed with `TENANT`.
* Organization API Resources are prefixed with `ORGANIZATION`.
*/
var APIResourceCategoryPrefixes;
(function (APIResourceCategoryPrefixes) {
    APIResourceCategoryPrefixes["MANAGEMENT"] = "TENANT";
    APIResourceCategoryPrefixes["ORGANIZATION"] = "ORGANIZATION";
})(APIResourceCategoryPrefixes || (APIResourceCategoryPrefixes = {}));
/*
* The API Resource category.
*/
var APIResourceCategories;
(function (APIResourceCategories) {
    APIResourceCategories["BUSINESS"] = "BUSINESS";
    APIResourceCategories["CONSOLE_FEATURE"] = "CONSOLE_FEATURE";
    APIResourceCategories["ORGANIZATION"] = "ORGANIZATION";
    APIResourceCategories["CONSOLE_ORG_LEVEL"] = "CONSOLE_ORG_LEVEL";
    APIResourceCategories["SYSTEM"] = "SYSTEM";
    APIResourceCategories["TENANT"] = "TENANT";
})(APIResourceCategories || (APIResourceCategories = {}));

export { APIResourceCategories, APIResourceCategoryPrefixes, APIResourceType, APIResourcesConstants };
