import _extends from '../../../../../../../@babel_runtime@7.24.5/node_modules/@babel/runtime/helpers/esm/extends.js';
import { clsx } from '../../../../../../../clsx@1.2.1/node_modules/clsx/dist/clsx.m.js';
import PropTypes from '../../../../../../../prop-types@15.8.1/node_modules/prop-types/index.js';
import React__default from 'react';
import { useWidthProp, useVerticalAlignProp, useValueAndKey, useTextAlignProp, useMultipleProp, useKeyOnly } from '../../lib/classNameBuilders.js';
import { every, disallow, multipleProp } from '../../lib/customPropTypes.js';
import { createShorthandFactory } from '../../lib/factories.js';
import getUnhandledProps from '../../lib/getUnhandledProps.js';
import getElementType from '../../lib/getElementType.js';
import { COLORS, WIDTHS, FLOATS, VISIBILITY, TEXT_ALIGNMENTS, VERTICAL_ALIGNMENTS } from '../../lib/SUI.js';

/**
 * A column sub-component for Grid.
 */

function GridColumn(props) {
  var children = props.children,
      className = props.className,
      computer = props.computer,
      color = props.color,
      floated = props.floated,
      largeScreen = props.largeScreen,
      mobile = props.mobile,
      only = props.only,
      stretched = props.stretched,
      tablet = props.tablet,
      textAlign = props.textAlign,
      verticalAlign = props.verticalAlign,
      widescreen = props.widescreen,
      width = props.width;
  var classes = clsx(color, useKeyOnly(stretched, 'stretched'), useMultipleProp(only, 'only'), useTextAlignProp(textAlign), useValueAndKey(floated, 'floated'), useVerticalAlignProp(verticalAlign), useWidthProp(computer, 'wide computer'), useWidthProp(largeScreen, 'wide large screen'), useWidthProp(mobile, 'wide mobile'), useWidthProp(tablet, 'wide tablet'), useWidthProp(widescreen, 'wide widescreen'), useWidthProp(width, 'wide'), 'column', className);
  var rest = getUnhandledProps(GridColumn, props);
  var ElementType = getElementType(GridColumn, props);
  return /*#__PURE__*/React__default.createElement(ElementType, _extends({}, rest, {
    className: classes
  }), children);
}

GridColumn.handledProps = ["as", "children", "className", "color", "computer", "floated", "largeScreen", "mobile", "only", "stretched", "tablet", "textAlign", "verticalAlign", "widescreen", "width"];
GridColumn.propTypes = process.env.NODE_ENV !== "production" ? {
  /** An element type to render as (string or function). */
  as: PropTypes.elementType,

  /** Primary content. */
  children: PropTypes.node,

  /** Additional classes. */
  className: PropTypes.string,

  /** A grid column can be colored. */
  color: PropTypes.oneOf(COLORS),

  /** A column can specify a width for a computer. */
  computer: every([disallow(['width']), PropTypes.oneOf(WIDTHS)]),

  /** A column can sit flush against the left or right edge of a row. */
  floated: PropTypes.oneOf(FLOATS),

  /** A column can specify a width for a large screen device. */
  largeScreen: every([disallow(['width']), PropTypes.oneOf(WIDTHS)]),

  /** A column can specify a width for a mobile device. */
  mobile: every([disallow(['width']), PropTypes.oneOf(WIDTHS)]),

  /** A column can appear only for a specific device, or screen sizes. */
  only: multipleProp(VISIBILITY),

  /** A column can stretch its contents to take up the entire grid or row height. */
  stretched: PropTypes.bool,

  /** A column can specify a width for a tablet device. */
  tablet: every([disallow(['width']), PropTypes.oneOf(WIDTHS)]),

  /** A column can specify its text alignment. */
  textAlign: PropTypes.oneOf(TEXT_ALIGNMENTS),

  /** A column can specify its vertical alignment to have all its columns vertically centered. */
  verticalAlign: PropTypes.oneOf(VERTICAL_ALIGNMENTS),

  /** A column can specify a width for a wide screen device. */
  widescreen: every([disallow(['width']), PropTypes.oneOf(WIDTHS)]),

  /** Represents width of column. */
  width: every([disallow(['computer', 'largeScreen', 'mobile', 'tablet', 'widescreen']), PropTypes.oneOf(WIDTHS)])
} : {};
GridColumn.create = createShorthandFactory(GridColumn, function (children) {
  return {
    children: children
  };
});

export { GridColumn as default };
