import _extends from '../../../../../../../@babel_runtime@7.24.5/node_modules/@babel/runtime/helpers/esm/extends.js';
import without from '../../../../../../../lodash-es@4.17.21/node_modules/lodash-es/without.js';
import { clsx } from '../../../../../../../clsx@1.2.1/node_modules/clsx/dist/clsx.m.js';
import PropTypes from '../../../../../../../prop-types@15.8.1/node_modules/prop-types/index.js';
import React__default from 'react';
import { isNil } from '../../lib/childrenUtils.js';
import { useTextAlignProp, useKeyOrValueAndKey, useKeyOnly, useValueAndKey } from '../../lib/classNameBuilders.js';
import { contentShorthand, every, disallow, itemShorthand } from '../../lib/customPropTypes.js';
import getUnhandledProps from '../../lib/getUnhandledProps.js';
import getElementType from '../../lib/getElementType.js';
import { COLORS, FLOATS, SIZES, TEXT_ALIGNMENTS } from '../../lib/SUI.js';
import Icon from '../Icon/Icon.js';
import Image from '../Image/Image.js';
import HeaderSubheader from './HeaderSubheader.js';
import HeaderContent from './HeaderContent.js';

/**
 * A header provides a short summary of content
 */

function Header(props) {
  var attached = props.attached,
      block = props.block,
      children = props.children,
      className = props.className,
      color = props.color,
      content = props.content,
      disabled = props.disabled,
      dividing = props.dividing,
      floated = props.floated,
      icon = props.icon,
      image = props.image,
      inverted = props.inverted,
      size = props.size,
      sub = props.sub,
      subheader = props.subheader,
      textAlign = props.textAlign;
  var classes = clsx('ui', color, size, useKeyOnly(block, 'block'), useKeyOnly(disabled, 'disabled'), useKeyOnly(dividing, 'dividing'), useValueAndKey(floated, 'floated'), useKeyOnly(icon === true, 'icon'), useKeyOnly(image === true, 'image'), useKeyOnly(inverted, 'inverted'), useKeyOnly(sub, 'sub'), useKeyOrValueAndKey(attached, 'attached'), useTextAlignProp(textAlign), 'header', className);
  var rest = getUnhandledProps(Header, props);
  var ElementType = getElementType(Header, props);

  if (!isNil(children)) {
    return /*#__PURE__*/React__default.createElement(ElementType, _extends({}, rest, {
      className: classes
    }), children);
  }

  var iconElement = Icon.create(icon, {
    autoGenerateKey: false
  });
  var imageElement = Image.create(image, {
    autoGenerateKey: false
  });
  var subheaderElement = HeaderSubheader.create(subheader, {
    autoGenerateKey: false
  });

  if (iconElement || imageElement) {
    return /*#__PURE__*/React__default.createElement(ElementType, _extends({}, rest, {
      className: classes
    }), iconElement || imageElement, (content || subheaderElement) && /*#__PURE__*/React__default.createElement(HeaderContent, null, content, subheaderElement));
  }

  return /*#__PURE__*/React__default.createElement(ElementType, _extends({}, rest, {
    className: classes
  }), content, subheaderElement);
}

Header.handledProps = ["as", "attached", "block", "children", "className", "color", "content", "disabled", "dividing", "floated", "icon", "image", "inverted", "size", "sub", "subheader", "textAlign"];
Header.propTypes = process.env.NODE_ENV !== "production" ? {
  /** An element type to render as (string or function). */
  as: PropTypes.elementType,

  /** Attach header  to other content, like a segment. */
  attached: PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(['top', 'bottom'])]),

  /** Format header to appear inside a content block. */
  block: PropTypes.bool,

  /** Primary content. */
  children: PropTypes.node,

  /** Additional classes. */
  className: PropTypes.string,

  /** Color of the header. */
  color: PropTypes.oneOf(COLORS),

  /** Shorthand for primary content. */
  content: contentShorthand,

  /** Show that the header is inactive. */
  disabled: PropTypes.bool,

  /** Divide header from the content below it. */
  dividing: PropTypes.bool,

  /** Header can sit to the left or right of other content. */
  floated: PropTypes.oneOf(FLOATS),

  /** Add an icon by icon name or pass an Icon. */
  icon: every([disallow(['image']), PropTypes.oneOfType([PropTypes.bool, itemShorthand])]),

  /** Add an image by img src or pass an Image. */
  image: every([disallow(['icon']), PropTypes.oneOfType([PropTypes.bool, itemShorthand])]),

  /** Inverts the color of the header for dark backgrounds. */
  inverted: PropTypes.bool,

  /** Content headings are sized with em and are based on the font-size of their container. */
  size: PropTypes.oneOf(without(SIZES, 'big', 'massive', 'mini')),

  /** Headers may be formatted to label smaller or de-emphasized content. */
  sub: PropTypes.bool,

  /** Shorthand for Header.Subheader. */
  subheader: itemShorthand,

  /** Align header content. */
  textAlign: PropTypes.oneOf(TEXT_ALIGNMENTS)
} : {};
Header.Content = HeaderContent;
Header.Subheader = HeaderSubheader;

export { Header as default };
