import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { EmptyPlaceholder, TabPageLayout } from '@thiva/react-components';
import React__default, { useState, useEffect } from 'react';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import { history, getEmptyPlaceholderIllustrations } from '@thiva/admin.core.v1';
import { useAPIResourceDetails } from '../api/api-resources.js';
import '../components/api-resources-list.js';
import { EditAPIResource } from '../components/edit-api-resource.js';
import { APIResourceType, APIResourcesConstants } from '../constants/api-resources-constants.js';
import { APIResourceUtils } from '../utils/api-resource-utils.js';
import { useTranslation } from '../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';
import { useSelector } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const APIResourcesEditPage = (props) => {
    const { ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    const allowedScopes = useSelector((state) => { var _a; return (_a = state === null || state === void 0 ? void 0 : state.auth) === null || _a === void 0 ? void 0 : _a.allowedScopes; });
    const [isReadOnly, setReadOnly] = useState(false);
    const [apiResourceId, setAPIResourceId] = useState(null);
    const featureConfig = useSelector((state) => state.config.ui.features);
    const path = history.location.pathname.split("/");
    const categoryId = path[path.length - 2];
    const { data: apiResourceData, isLoading: isAPIResourceDatatLoading, error: apiResourceDataFetchRequestError, mutate: updateAPIResource } = useAPIResourceDetails(apiResourceId);
    /**
     * The following useEffect is used to set the API resource id from the path
     */
    useEffect(() => {
        setAPIResourceIdFromPath();
    }, []);
    /**
     * The following useEffect is used to handle if the user has the required scopes to update the API resource
     */
    useEffect(() => {
        if (!apiResourceData) {
            return;
        }
        const updateForbidden = !APIResourceUtils.isAPIResourceUpdateAllowed(featureConfig, allowedScopes);
        const isSytemAPIResource = APIResourceUtils.isSystemAPI(apiResourceData === null || apiResourceData === void 0 ? void 0 : apiResourceData.type);
        if (updateForbidden || isSytemAPIResource) {
            setReadOnly(true);
        }
    }, [apiResourceData]);
    /**
     * The following useEffect is used to handle if any error occurs while fetching the API resource
     */
    useEffect(() => {
        if (apiResourceDataFetchRequestError) {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.getAPIResource" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.getAPIResource" +
                    ".genericError.message")
            }));
        }
    }, [apiResourceDataFetchRequestError]);
    /**
     * set API resource id from the URL path
     */
    const setAPIResourceIdFromPath = () => {
        const path = history.location.pathname.split("/");
        const id = path[path.length - 1];
        setAPIResourceId(id);
    };
    /**
     * go back to API resources list section
     */
    const handleBackButtonClick = () => {
        if (categoryId === APIResourceType.MANAGEMENT || categoryId === APIResourceType.ORGANIZATION) {
            history.push(APIResourcesConstants.getPaths().get("API_RESOURCES_CATEGORY")
                .replace(":categoryId", categoryId));
        }
        else {
            history.push(APIResourcesConstants.getPaths().get("API_RESOURCES"));
        }
    };
    return ((!isAPIResourceDatatLoading && !apiResourceData) || apiResourceDataFetchRequestError
        ? (React__default.createElement(EmptyPlaceholder, { subtitle: [t("extensions:develop.apiResource.tabs.apiResourceError.subtitles.0"),
                t("extensions:develop.apiResource.tabs.apiResourceError.subtitles.1")], title: t("extensions:develop.apiResource.tabs.apiResourceError.title"), image: getEmptyPlaceholderIllustrations().emptySearch, imageSize: "tiny" }))
        : (React__default.createElement(TabPageLayout, { isLoading: isAPIResourceDatatLoading, title: apiResourceData === null || apiResourceData === void 0 ? void 0 : apiResourceData.name, pageTitle: t("extensions:develop.apiResource.tabs.title"), loadingStateOptions: {
                count: 5,
                imageType: "circular"
            }, backButton: {
                "data-testid": `${componentId}-back-button`,
                onClick: handleBackButtonClick,
                text: categoryId === APIResourceType.MANAGEMENT
                    ? t("pages:rolesEdit.backButton", { type: "Management APIs" })
                    : categoryId === APIResourceType.ORGANIZATION
                        ? t("pages:rolesEdit.backButton", { type: "Organization APIs" })
                        : t("pages:rolesEdit.backButton", { type: "APIs" })
            }, titleTextAlign: "left", bottomMargin: false, pageHeaderMaxWidth: true },
            React__default.createElement(EditAPIResource, { apiResourceData: apiResourceData, isAPIResourceDataLoading: isAPIResourceDatatLoading, featureConfig: featureConfig, isReadOnly: isReadOnly, mutateAPIResource: updateAPIResource }))));
};
/**
 * Default props for the component.
 */
APIResourcesEditPage.defaultProps = {
    "data-componentid": "api-resource-edit"
};

export { APIResourcesEditPage as default };
