import { BuildingGearIcon, ChevronRightIcon, HierarchyIcon } from '../node_modules/.pnpm/@oxygen-ui_react-icons@1.11.0_react-dom@18.3.1_react@18.3.1_typescript@4.9.5/node_modules/@oxygen-ui/react-icons/dist/index.esm.js';
import Grid from '../node_modules/.pnpm/@oxygen-ui_react@1.11.0_@emotion_react@11.11.4_@emotion_styled@11.11.5_@mui_icons-material@5._ozrhvdqkt7gkjaiaow64dhg7sa/node_modules/@oxygen-ui/react/Grid/Grid.js';
import { IdentityAppsApiException } from '@thiva/core/exceptions';
import { AlertLevels } from '@thiva/core/models';
import { addAlert } from '@thiva/core/store';
import { useDocumentation, PageLayout, PrimaryButton, DocumentationLink, EmphasizedSegment, GenericIcon, ListLayout, EmptyPlaceholder } from '@thiva/react-components';
import React__default, { useState, useEffect } from 'react';
import '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/index.js';
import Divider from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Divider/Divider.js';
import Icon from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/Icon/Icon.js';
import List from '../node_modules/.pnpm/semantic-ui-react@2.1.5_react-dom@18.3.1_react@18.3.1/node_modules/semantic-ui-react/dist/es/elements/List/List.js';
import { history, AdvancedSearchWithBasicFilters, getEmptyPlaceholderIllustrations } from '@thiva/admin.core.v1';
import { useAPIResources } from '../api/api-resources.js';
import { APIResourcesList } from '../components/api-resources-list.js';
import '../components/api-resource-panes/authorization-api-resource.js';
import '../components/api-resource-panes/general-api-resource.js';
import '../components/api-resource-panes/permission-api-resource.js';
import '../components/api-resource-panes/permission-list-api-resource.js';
import { AddAPIResource } from '../components/wizard/add-api-resource.js';
import '../components/wizard/add-api-resource-permission.js';
import { APIResourcesConstants, APIResourceType } from '../constants/api-resources-constants.js';
import { APIResourceUtils } from '../utils/api-resource-utils.js';
import { useTranslation } from '../node_modules/.pnpm/react-i18next@11.18.6_i18next@21.10.0_react-dom@18.3.1_react@18.3.1/node_modules/react-i18next/dist/es/useTranslation.js';
import { useDispatch } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useDispatch.js';
import { useSelector } from '../node_modules/.pnpm/react-redux@7.2.9_react-dom@18.3.1_react@18.3.1/node_modules/react-redux/es/hooks/useSelector.js';

/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
const APIResourcesPage = (props) => {
    const { ["data-componentid"]: componentId } = props;
    const { t } = useTranslation();
    const dispatch = useDispatch();
    const { getLink } = useDocumentation();
    const [activePage, setActivePage] = useState(1);
    const [showWizard, setShowWizard] = useState(false);
    const [isListUpdated, setListUpdated] = useState(false);
    const [triggerClearQuery, setTriggerClearQuery] = useState(false);
    const [searchQuery, setSearchQuery] = useState("");
    const [apiResourcesList, setAPIResourcesList] = useState([]);
    const [after, setAfter] = useState(undefined);
    const [before, setBefore] = useState(undefined);
    const [nextAfter, setNextAfter] = useState(undefined);
    const [nextBefore, setNextBefore] = useState(undefined);
    const [filter, setFilter] = useState(`type eq ${APIResourcesConstants.BUSINESS}`);
    const [attributes] = useState(APIResourcesConstants.PROPERTIES);
    const featureConfig = useSelector((state) => state.config.ui.features);
    const allowedScopes = useSelector((state) => { var _a; return (_a = state === null || state === void 0 ? void 0 : state.auth) === null || _a === void 0 ? void 0 : _a.allowedScopes; });
    const { data: apiResourcesListData, isLoading: isAPIResourcesListLoading, error: apiResourcesFetchRequestError, mutate: mutateAPIResourcesFetchRequest } = useAPIResources(after, before, filter, true, attributes);
    /**
     * Update the API resources list.
     */
    useEffect(() => {
        var _a;
        if (apiResourcesListData instanceof IdentityAppsApiException) {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.getAPIResources" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.getAPIResources" +
                    ".genericError.message")
            }));
            return;
        }
        if (apiResourcesListData) {
            const apiResourceList = apiResourcesListData.apiResources.map((apiResource) => apiResource);
            setNextAfter(undefined);
            setNextBefore(undefined);
            if (apiResourcesListData.links && apiResourcesListData.links.length !== 0) {
                (_a = apiResourcesListData.links) === null || _a === void 0 ? void 0 : _a.forEach((value) => {
                    switch (value.rel) {
                        case APIResourcesConstants.NEXT_REL:
                            setNextAfter(value.href.split(`${APIResourcesConstants.AFTER}=`)[1]);
                            break;
                        case APIResourcesConstants.PREVIOUS_REL:
                            setNextBefore(value.href.split(`${APIResourcesConstants.BEFORE}=`)[1]);
                            break;
                    }
                });
            }
            setAPIResourcesList(apiResourceList);
        }
    }, [apiResourcesListData]);
    /**
     * The following useEffect is used to handle if any error occurs while fetching the API resources list
     */
    useEffect(() => {
        if (apiResourcesFetchRequestError) {
            dispatch(addAlert({
                description: t("extensions:develop.apiResource.notifications.getAPIResources" +
                    ".genericError.description"),
                level: AlertLevels.ERROR,
                message: t("extensions:develop.apiResource.notifications.getAPIResources" +
                    ".genericError.message")
            }));
        }
    }, [apiResourcesFetchRequestError]);
    /**
     * The following useEffect is used to update the API resources list once a mutate function is called.
     */
    useEffect(() => {
        if (isListUpdated) {
            mutateAPIResourcesFetchRequest();
            setListUpdated(false);
        }
    }, [isListUpdated]);
    /**
     * The following useEffect is used to update the filter value
     */
    useEffect(() => {
        const typeFilter = `type eq ${APIResourcesConstants.BUSINESS}`;
        if (searchQuery) {
            setFilter(`${searchQuery} and ${typeFilter}`);
        }
        else {
            setFilter(typeFilter);
        }
    }, [searchQuery]);
    /**
     * edit the API resources list once a API resource is deleted
     */
    const onAPIResourceDelete = () => {
        setMutateAPIResourcesList();
    };
    /**
     * set the after and before values needed for the `mutateAPIResourcesFetchRequest`
     *
     * @param afterValue - after value
     * @param beforeValue - before value
     */
    const setMutateAPIResourcesList = (afterValue, beforeValue) => {
        // set the after and before values needed for the `mutateAPIResourcesFetchRequest`
        setAfter(afterValue);
        setBefore(beforeValue);
        setListUpdated(true);
    };
    /**
     * Handles the pagination change.
     *
     * @param event - Mouse event.
     * @param data - Pagination component data.
     */
    const handlePaginationChange = (event, data) => {
        const newPage = parseInt(data === null || data === void 0 ? void 0 : data.activePage);
        if (newPage > activePage) {
            setMutateAPIResourcesList(nextAfter, undefined);
        }
        else if (newPage < activePage) {
            setMutateAPIResourcesList(undefined, nextBefore);
        }
        setActivePage(newPage);
    };
    /**
     * Handles the `onFilter` callback action from the
     * api search component.
     *
     * @param query - Search query.
     */
    const handleApiFilter = (query) => {
        setSearchQuery(query);
    };
    /**
     * Handles the `onSearchQueryClear` callback action.
     */
    const handleSearchQueryClear = () => {
        setSearchQuery("");
        setTriggerClearQuery(!triggerClearQuery);
    };
    return (React__default.createElement(PageLayout, { action: APIResourceUtils.isAPIResourceCreateAllowed(featureConfig, allowedScopes)
            && (apiResourcesList === null || apiResourcesList === void 0 ? void 0 : apiResourcesList.length) > 0
            && (React__default.createElement(PrimaryButton, { "data-testid": `${componentId}-add-api-resources-button`, onClick: () => setShowWizard(true) },
                React__default.createElement(Icon, { name: "add" }),
                t("extensions:develop.apiResource.addApiResourceButton"))), pageTitle: t("extensions:develop.apiResource.pageHeader.title"), title: t("extensions:develop.apiResource.pageHeader.title"), description: (React__default.createElement(React__default.Fragment, null,
            t("extensions:develop.apiResource.pageHeader.description"),
            React__default.createElement(DocumentationLink, { link: getLink("develop.apiResources.learnMore") }, t("extensions:common.learnMore")))), "data-componentid": `${componentId}-page-layout`, "data-testid": `${componentId}-page-layout`, headingColumnWidth: "11", actionColumnWidth: "5" },
        React__default.createElement(EmphasizedSegment, { onClick: () => {
                history.push(APIResourcesConstants.getPaths().get("API_RESOURCES_CATEGORY")
                    .replace(":categoryId", APIResourceType.MANAGEMENT));
            }, className: "clickable", "data-componentid": `${componentId}-management-api-container` },
            React__default.createElement(List, null,
                React__default.createElement(List.Item, null,
                    React__default.createElement(Grid, { container: true, direction: "row", xs: 12, alignItems: "center" },
                        React__default.createElement(Grid, { xs: 10, alignContent: "center" },
                            React__default.createElement(GenericIcon, { verticalAlign: "middle", fill: "primary", transparent: true, icon: React__default.createElement(BuildingGearIcon, { size: "medium" }), spaced: "right", floated: "left", className: "mt-1" }),
                            React__default.createElement(List.Header, null, t("extensions:develop.apiResource.managementAPI.header")),
                            React__default.createElement(List.Description, null, t("extensions:develop.apiResource.managementAPI.description"))),
                        React__default.createElement(Grid, { xs: 2 },
                            React__default.createElement(GenericIcon, { verticalAlign: "middle", fill: "primary", transparent: true, icon: React__default.createElement(ChevronRightIcon, null), spaced: "right", floated: "right" })))))),
        React__default.createElement(EmphasizedSegment, { onClick: () => {
                history.push(APIResourcesConstants.getPaths().get("API_RESOURCES_CATEGORY")
                    .replace(":categoryId", APIResourceType.ORGANIZATION));
            }, className: "clickable", "data-componentid": `${componentId}-organization-api-container` },
            React__default.createElement(List, null,
                React__default.createElement(List.Item, null,
                    React__default.createElement(Grid, { container: true, direction: "row", xs: 12, alignItems: "center" },
                        React__default.createElement(Grid, { xs: 10, alignContent: "center" },
                            React__default.createElement(GenericIcon, { verticalAlign: "middle", fill: "primary", transparent: true, icon: React__default.createElement(HierarchyIcon, { size: "medium" }), spaced: "right", floated: "left", className: "mt-1" }),
                            React__default.createElement(List.Header, null, t("extensions:develop.apiResource.organizationAPI.header")),
                            React__default.createElement(List.Description, null, t("extensions:develop.apiResource.organizationAPI.description"))),
                        React__default.createElement(Grid, { xs: 2 },
                            React__default.createElement(GenericIcon, { verticalAlign: "middle", fill: "primary", transparent: true, icon: React__default.createElement(ChevronRightIcon, null), spaced: "right", floated: "right" })))))),
        React__default.createElement(Divider, { hidden: true }),
        React__default.createElement(ListLayout, { advancedSearch: (React__default.createElement(AdvancedSearchWithBasicFilters, { onFilter: handleApiFilter, filterAttributeOptions: [
                    {
                        key: 0,
                        text: t("common:name"),
                        value: "name"
                    }
                ], filterAttributePlaceholder: t("applications:advancedSearch.form" +
                    ".inputs.filterAttribute.placeholder"), filterConditionsPlaceholder: t("applications:advancedSearch.form" +
                    ".inputs.filterCondition.placeholder"), filterValuePlaceholder: t("applications:advancedSearch.form.inputs.filterValue" +
                    ".placeholder"), placeholder: "Search APIs by name", style: { minWidth: "425px" }, defaultSearchAttribute: "name", defaultSearchOperator: "co", triggerClearQuery: triggerClearQuery, "data-componentid": `${componentId}-list-advanced-search` })), showTopActionPanel: (!!searchQuery || (apiResourcesList === null || apiResourcesList === void 0 ? void 0 : apiResourcesList.length) > 0), "data-componentid": `${componentId}-api-resources-list-layout`, "data-testid": `${componentId}-api-resources-list-layout`, onPageChange: handlePaginationChange, showPagination: true, totalPages: APIResourcesConstants.DEFAULT_TOTAL_PAGES, totalListSize: apiResourcesList === null || apiResourcesList === void 0 ? void 0 : apiResourcesList.length, showPaginationPageLimit: false, isLoading: isAPIResourcesListLoading, activePage: activePage, paginationOptions: {
                disableNextButton: !nextAfter,
                disablePreviousButton: !nextBefore
            } }, apiResourcesFetchRequestError
            ? (React__default.createElement(EmptyPlaceholder, { subtitle: [t("extensions:develop.apiResource.apiResourceError.subtitles.0"),
                    t("extensions:develop.apiResource.apiResourceError.subtitles.1")], title: t("extensions:develop.apiResource.apiResourceError.title"), image: getEmptyPlaceholderIllustrations().genericError, imageSize: "tiny" }))
            : (React__default.createElement(APIResourcesList, { apiResourcesList: apiResourcesList, isAPIResourcesListLoading: isAPIResourcesListLoading, featureConfig: featureConfig, onAPIResourceDelete: onAPIResourceDelete, onSearchQueryClear: handleSearchQueryClear, searchQuery: searchQuery, categoryId: "custom", onEmptyListPlaceholderActionClicked: () => setShowWizard(true) }))),
        showWizard && (React__default.createElement(AddAPIResource, { "data-testid": `${componentId}-add-api-resource-wizard-modal`, closeWizard: () => setShowWizard(false) }))));
};
/**
 * Default props for the component.
 */
APIResourcesPage.defaultProps = {
    "data-componentid": "api-resources"
};

export { APIResourcesPage as default };
