/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { IdentityAppsApiException } from "@thiva/core/exceptions";
import { RequestErrorInterface, RequestResultInterface } from "@thiva/admin.core.v1/hooks/use-request";
import { APIResourceInterface, APIResourcePermissionInterface, APIResourcesListInterface, UpdatedAPIResourceInterface } from "../models";
/**
 * Get API resources for the identifier validation.
 * Only to be used for the identifier validation.
 *
 * @param filter - filter.
 * @returns `Promise<APIResourcesListInterface | IdentityAppsApiException>`
 */
export declare const getAPIResourcesForIdenitifierValidation: (filter: string) => Promise<APIResourcesListInterface>;
/**
 * Get API resources.
 *
 * @param after - after.
 * @param before - before.
 * @param filter - filter.
 * @param shouldFetch - whether to fetch or not.
 * @returns `Promise<APIResourcesListInterface>`
 * @throws `IdentityAppsApiException`
 */
export declare const useAPIResources: <Data = APIResourcesListInterface, Error_1 = RequestErrorInterface>(after?: string, before?: string, filter?: string, shouldFetch?: boolean, attributes?: string) => RequestResultInterface<Data, Error_1>;
/**
 *
 * @param apiResourceId - id of the API resource
 * @returns `Promise<APIResourceInterface>`
 * @throws `IdentityAppsApiException`
 */
export declare const useAPIResourceDetails: <Data = APIResourceInterface, Error_1 = RequestErrorInterface>(apiResourceId: string) => RequestResultInterface<Data, Error_1>;
/**
 * Get permissions of an API resource for the permission validation.
 * Only to be used for the permission validation.
 *
 * @param filter - filter.
 * @returns `Promise<APIResourcePermissionInterface[]>`
 * @throws `IdentityAppsApiException`
 */
export declare const getAPIResourcePermissions: (filter: string) => Promise<APIResourcePermissionInterface[]>;
/**
 * Delete an API resource.
 *
 * @param apiResourceId - UUID of the API resource that needed to be deleted.
 * @returns `Promise<null | IdentityAppsApiException>`
 * @throws `IdentityAppsApiException`
 */
export declare const deleteAPIResource: (apiResourceId: string) => Promise<null | IdentityAppsApiException>;
/**
 * Update an API resource.
 *
 * @param apiResourceId - UUID of the API resource that needed to be updated.
 * @param updateAPIResourceBody - Body of the API resource that needed to be updated.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
export declare const updateAPIResource: (apiResourceId: string, updateAPIResourceBody: UpdatedAPIResourceInterface) => Promise<null | IdentityAppsApiException>;
/**
 * Create an API resource.
 *
 * @param apiResourceBody - Body of the API resource that needed to be created.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
export declare const createAPIResource: (apiResourceBody: APIResourceInterface) => Promise<APIResourceInterface | void>;
/**
 * Delete a scope from an API resource.
 *
 * @param apiResourceId - UUID of the API resource.
 * @param deleteScopeName - Name of the scope that needs to be deleted.
 * @returns `Promise<null | IdentityAppsApiException>`
 */
export declare const deleteScopeFromAPIResource: (apiResourceId: string, deletingScopeName: string) => Promise<null | IdentityAppsApiException>;
