/**
 * Copyright (c) 2023-2024, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { IdentifiableComponentInterface, SBACInterface } from "@thiva/core/models";
import { FunctionComponent, SyntheticEvent } from "react";
import { FeatureConfigInterface } from "@thiva/admin.core.v1";
import { APIResourceInterface } from "../models";
/**
 * Prop types for the API resources list component.
 */
interface APIResourcesListProps extends SBACInterface<FeatureConfigInterface>, IdentifiableComponentInterface {
    /**
     * List of API Resources
     */
    apiResourcesList: APIResourceInterface[];
    /**
     * show if API resources list is still loading
     */
    isAPIResourcesListLoading: boolean;
    /**
     * On API resource delete callback.
     */
    onAPIResourceDelete?: () => void;
    /**
     * On list item select callback.
     */
    onListItemClick?: (event: SyntheticEvent, apiResource: APIResourceInterface) => void;
    /**
     * Show list item actions.
     */
    showListItemActions?: boolean;
    /**
     * API Category
     */
    categoryId: string;
    /**
     * Search query for the list.
     */
    searchQuery?: string;
    /**
     * Callback for the search query clear action.
     */
    onSearchQueryClear?: () => void;
    /**
     * Callback to be fired when the empty list placeholder action is clicked.
     */
    onEmptyListPlaceholderActionClicked?: () => void;
}
/**
 * Users info page.
 *
 * @returns The users list table.
 */
export declare const APIResourcesList: FunctionComponent<APIResourcesListProps>;
export {};
