/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { IdentifiableComponentInterface, SBACInterface } from "@thiva/core/models";
import { FormValue } from "@thiva/forms";
import { FunctionComponent } from "react";
import { FeatureConfigInterface } from "@thiva/admin.core.v1";
import { APIResourcePermissionInterface } from "../../../models";
/**
 * Prop-types for the API resources page component.
 */
interface AddAPIResourcePermissionsInterface extends SBACInterface<FeatureConfigInterface>, IdentifiableComponentInterface {
    /**
     * Initial permission list.
     */
    initialPermissions: Map<string, APIResourcePermissionInterface>;
    /**
     * Trigger add permission form submit action.
     */
    triggerAddPermission: boolean;
    /**
     * Permission value loading status.
     */
    isPermissionValidationLoading: boolean;
    /**
     * Set the trigger add permission form submit action.
     */
    setAddPermission: () => void;
    /**
     * Set the permission list.
     */
    setPermissionsList: (permissions: Map<string, APIResourcePermissionInterface>) => void;
    /**
     * Set the latest permission form values.
     */
    setLatestPermissionFormValues: (formValue: Map<string, FormValue>) => void;
    /**
     * Set the permission value loading status.
     */
    setPermissionValidationLoading: (status: boolean) => void;
}
/**
 * API Resources listing page.
 *
 * @param props - Props injected to the component.
 * @returns API Resources Page component
 */
export declare const AddAPIResourcePermissions: FunctionComponent<AddAPIResourcePermissionsInterface>;
export {};
