/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/**
 * Class containing API resources constants.
 */
export declare class APIResourcesConstants {
    /**
     * Private constructor to avoid object instantiation from outside
     * the class.
     *
     */
    private constructor();
    static readonly NEXT_REL: string;
    static readonly PREVIOUS_REL: string;
    static readonly AFTER: string;
    static readonly BEFORE: string;
    static readonly DEFAULT_TOTAL_PAGES: number;
    static readonly API_RESOURCE_DIR: string;
    static readonly SYSTEM: string;
    static readonly SYSTEM_ORG: string;
    static readonly SYSTEM_FEATURE: string;
    static readonly BUSINESS: string;
    static readonly PROPERTIES: string;
    static readonly IS_CHOREO_API: string;
    /**
     * Get the API resource paths as a map.
     *
     * @returns `Map<string, string>`
     */
    static getPaths(): Map<string, string>;
    /**
     * To check whether the given value is a valid permission identifier.
     *
     * @param value - permission identifier
     * @returns boolean - true if the value is a valid permission identifier
     */
    static checkValidPermissionIdentifier: (value: string) => boolean;
}
export declare enum APIResourceType {
    MANAGEMENT = "management",
    ORGANIZATION = "organization",
    BUSINESS = "business"
}
export declare enum APIResourceCategoryPrefixes {
    MANAGEMENT = "TENANT",
    ORGANIZATION = "ORGANIZATION"
}
export declare enum APIResourceCategories {
    BUSINESS = "BUSINESS",
    CONSOLE_FEATURE = "CONSOLE_FEATURE",
    ORGANIZATION = "ORGANIZATION",
    CONSOLE_ORG_LEVEL = "CONSOLE_ORG_LEVEL",
    SYSTEM = "SYSTEM",
    TENANT = "TENANT"
}
