/**
 * Copyright (c) 2023, WSO2 LLC. (https://www.wso2.com).
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { FeatureConfigInterface } from "@thiva/admin.core.v1";
import { Property } from "../models/api-resources";
export declare class APIResourceUtils {
    /**
     * Private constructor to avoid object instantiation from outside
     * the class.
     */
    private constructor();
    /**
     * Check whether the API resource read is allowed.
     *
     * @param featureConfig - Feature config.
     * @param allowedScopes - Allowed scopes.
     * @returns True if the API resource read is allowed.
     */
    static isAPIResourceReadAllowed(featureConfig: FeatureConfigInterface, allowedScopes: string): boolean;
    /**
     * Check whether the API resource update is allowed.
     *
     * @param featureConfig - Feature config.
     * @param allowedScopes - Allowed scopes.
     * @returns True if the API resource update is allowed.
     */
    static isAPIResourceUpdateAllowed(featureConfig: FeatureConfigInterface, allowedScopes: string): boolean;
    /**
     * Check whether the API resource create is allowed.
     *
     * @param featureConfig - Feature config.
     * @param allowedScopes - Allowed scopes.
     * @returns True if the API resource create is allowed.
     */
    static isAPIResourceCreateAllowed(featureConfig: FeatureConfigInterface, allowedScopes: string): boolean;
    /**
     * Check whether the API resource delete is allowed.
     *
     * @param featureConfig - Feature config.
     * @param allowedScopes - Allowed scopes.
     * @returns True if the API resource delete is allowed.
     */
    static isAPIResourceDeleteAllowed(featureConfig: FeatureConfigInterface, allowedScopes: string): boolean;
    /**
     * Check whether the API resource is a system API.
     *
     * @param type - API Resource type.
     * @returns True if the API resource is a system API.
     */
    static isSystemAPI(type: string): boolean;
    static resolveApiResourceGroup: (groupName: string) => string;
    static resolveApiResourceGroupDisplayName: (groupName: string) => string;
    static resolveApiResourceGroupDescription: (groupName: string) => string;
    /**
     * Checks if the API resource is managed by Choreo.
     *
     * @param properties - API resource properties.
     * @returns - `true` if the API resource is managed by Choreo and `false` otherwise.
     */
    static checkIfAPIResourcePropertyManaged: (properties: Property[]) => boolean;
}
